@@ -24,11 +24,11 @@
 //! ```
 
 use pixi_cli::{
-    add,
+    add, build,
     cli_config::{
         DependencyConfig, GitRev, LockFileUpdateConfig, NoInstallConfig, WorkspaceConfig,
     },
-    init, install, lock, remove, search, task, update, workspace,
+    global, init, install, lock, remove, search, task, update, workspace,
 };
 use pixi_core::DependencyType;
 use std::{
@@ -38,6 +38,7 @@ use std::{
     pin::Pin,
     str::FromStr,
 };
+use typed_path::Utf8NativePathBuf;
 
 use futures::FutureExt;
 use pixi_manifest::{EnvironmentName, FeatureName, SpecType, task::Dependency};
@@ -87,6 +88,11 @@ impl InitBuilder {
         self.args.format = Some(format);
         self
     }
+
+    pub fn with_platforms(mut self, platforms: Vec<Platform>) -> Self {
+        self.args.platforms = platforms.into_iter().map(|p| p.to_string()).collect();
+        self
+    }
 }
 
 impl IntoFuture for InitBuilder {
@@ -239,6 +245,11 @@ impl AddBuilder {
         }
         self
     }
+
+    pub fn with_no_install(mut self, no_install: bool) -> Self {
+        self.args.no_install_config.no_install = no_install;
+        self
+    }
 }
 
 impl HasDependencyConfig for AddBuilder {
@@ -573,6 +584,11 @@ impl UpdateBuilder {
         self.args.json = json;
         self
     }
+
+    pub fn with_no_install(mut self, no_install: bool) -> Self {
+        self.args.no_install = no_install;
+        self
+    }
 }
 
 impl IntoFuture for UpdateBuilder {
@@ -597,3 +613,105 @@ impl IntoFuture for LockBuilder {
         lock::execute(self.args).boxed_local()
     }
 }
+
+/// Contains the arguments to pass to [`build::execute()`]. Call `.await` to call
+/// the CLI execute method and await the result at the same time.
+pub struct BuildBuilder {
+    pub args: build::Args,
+}
+
+impl BuildBuilder {
+    /// Set the target platform for the build
+    pub fn with_target_platform(mut self, platform: Platform) -> Self {
+        self.args.target_platform = platform;
+        self
+    }
+
+    /// Set the build platform for the build
+    pub fn with_build_platform(mut self, platform: Platform) -> Self {
+        self.args.build_platform = platform;
+        self
+    }
+
+    /// Set the output directory for built artifacts
+    pub fn with_output_dir(mut self, output_dir: impl Into<PathBuf>) -> Self {
+        self.args.output_dir = output_dir.into();
+        self
+    }
+
+    /// Set the build directory for incremental builds
+    pub fn with_build_dir(mut self, build_dir: impl Into<PathBuf>) -> Self {
+        self.args.build_dir = Some(build_dir.into());
+        self
+    }
+
+    /// Set whether to clean the build directory before building
+    pub fn with_clean(mut self, clean: bool) -> Self {
+        self.args.clean = clean;
+        self
+    }
+
+    /// Set the path to the package manifest or directory
+    pub fn with_path(mut self, path: impl Into<PathBuf>) -> Self {
+        self.args.path = Some(path.into());
+        self
+    }
+}
+
+impl IntoFuture for BuildBuilder {
+    type Output = miette::Result<()>;
+    type IntoFuture = Pin<Box<dyn Future<Output = Self::Output> + 'static>>;
+
+    fn into_future(self) -> Self::IntoFuture {
+        build::execute(self.args).boxed_local()
+    }
+}
+
+/// Contains the arguments to pass to [`global::execute()`]. Call `.await` to call
+/// the CLI execute method and await the result at the same time.
+pub struct GlobalInstallBuilder {
+    args: global::install::Args,
+    tmpdir: PathBuf,
+}
+
+impl GlobalInstallBuilder {
+    /// Create a new GlobalInstallBuilder
+    pub fn new(
+        tmpdir: PathBuf,
+        backend_override: Option<pixi_build_frontend::BackendOverride>,
+    ) -> Self {
+        let mut args = global::install::Args::default();
+        args.backend_override = backend_override;
+        Self { args, tmpdir }
+    }
+
+    pub fn with_path(mut self, path: impl ToString) -> Self {
+        self.args.packages.path = Some(Into::<Utf8NativePathBuf>::into(path.to_string()));
+        self
+    }
+
+    pub fn with_force_reinstall(mut self, force_reinstall: bool) -> Self {
+        self.args.force_reinstall = force_reinstall;
+        self
+    }
+}
+
+impl IntoFuture for GlobalInstallBuilder {
+    type Output = miette::Result<()>;
+    type IntoFuture = Pin<Box<dyn Future<Output = Self::Output> + 'static>>;
+
+    fn into_future(self) -> Self::IntoFuture {
+        let args = global::Args {
+            command: global::Command::Install(self.args),
+        };
+
+        temp_env::async_with_vars(
+            [
+                ("PIXI_HOME", Some(self.tmpdir.clone())),
+                ("PIXI_CACHE_DIR", Some(self.tmpdir.clone())),
+            ],
+            async { global::execute(args).await },
+        )
+        .boxed_local()
+    }
+}
