@@ -21,7 +21,7 @@ use pixi_cli::cli_config::{
     ChannelsConfig, LockFileUpdateConfig, NoInstallConfig, WorkspaceConfig,
 };
 use pixi_cli::{
-    add,
+    add, build,
     init::{self, GitAttributes},
     install::Args,
     lock, remove, run, search,
@@ -46,8 +46,9 @@ use thiserror::Error;
 
 use self::builders::{HasDependencyConfig, RemoveBuilder};
 use crate::common::builders::{
-    AddBuilder, InitBuilder, InstallBuilder, ProjectChannelAddBuilder, ProjectChannelRemoveBuilder,
-    ProjectEnvironmentAddBuilder, TaskAddBuilder, TaskAliasBuilder, UpdateBuilder,
+    AddBuilder, BuildBuilder, GlobalInstallBuilder, InitBuilder, InstallBuilder,
+    ProjectChannelAddBuilder, ProjectChannelRemoveBuilder, ProjectEnvironmentAddBuilder,
+    TaskAddBuilder, TaskAliasBuilder, UpdateBuilder,
 };
 
 const DEFAULT_PROJECT_CONFIG: &str = r#"
@@ -57,6 +58,16 @@ default-channels = ["https://prefix.dev/conda-forge"]
 disable-sharded = false
 "#;
 
+/// Returns the path to the root of the workspace.
+pub(crate) fn cargo_workspace_dir() -> &'static Path {
+    Path::new(env!("CARGO_WORKSPACE_DIR"))
+}
+
+/// Returns the path to the `tests/data/workspaces` directory in the repository.
+pub(crate) fn workspaces_dir() -> PathBuf {
+    cargo_workspace_dir().join("tests/data/workspaces")
+}
+
 /// To control the pixi process
 pub struct PixiControl {
     /// The path to the project working file
@@ -125,6 +136,13 @@ pub trait LockFileExt {
         platform: Platform,
         package: &str,
     ) -> Option<UrlOrPath>;
+
+    fn get_pypi_package(
+        &self,
+        environment: &str,
+        platform: Platform,
+        package: &str,
+    ) -> Option<LockedPackageRef>;
 }
 
 impl LockFileExt for LockFile {
@@ -202,6 +220,18 @@ impl LockFileExt for LockFile {
             .map(|(data, _)| data.version.to_string())
     }
 
+    fn get_pypi_package(
+        &self,
+        environment: &str,
+        platform: Platform,
+        package: &str,
+    ) -> Option<LockedPackageRef> {
+        self.environment(environment).and_then(|env| {
+            env.packages(platform)
+                .and_then(|mut packages| packages.find(|p| p.name() == package))
+        })
+    }
+
     fn get_pypi_package_url(
         &self,
         environment: &str,
@@ -375,6 +405,12 @@ impl PixiControl {
         self.add_multiple(vec![spec])
     }
 
+    /// Add a pypi dependency to the project. Returns an [`AddBuilder`].
+    /// To execute the command and await the result, call `.await` on the return value.
+    pub fn add_pypi(&self, spec: &str) -> AddBuilder {
+        self.add_multiple(vec![spec]).set_pypi(true)
+    }
+
     /// Add dependencies to the project. Returns an [`AddBuilder`].
     /// To execute the command and await the result, call `.await` on the return value.
     pub fn add_multiple(&self, specs: Vec<&str>) -> AddBuilder {
@@ -598,6 +634,15 @@ impl PixiControl {
         }
     }
 
+    /// Returns a [`GlobalInstallBuilder`].
+    /// To execute the command and await the result, call `.await` on the return value.
+    pub fn global_install(&self) -> GlobalInstallBuilder {
+        GlobalInstallBuilder::new(
+            self.tmpdir.path().to_path_buf(),
+            self.backend_override.clone(),
+        )
+    }
+
     /// Returns a [`UpdateBuilder]. To execute the command and await the result
     /// call `.await` on the return value.
     pub fn update(&self) -> UpdateBuilder {
@@ -622,7 +667,7 @@ impl PixiControl {
     /// [`Self::update_lock_file`].
     pub async fn lock_file(&self) -> miette::Result<LockFile> {
         let workspace = Workspace::from_path(&self.manifest_path())?;
-        workspace.load_lock_file().await
+        workspace.load_lock_file().await?.into_lock_file()
     }
 
     /// Load the current lock-file and makes sure that its up to date with the
@@ -652,6 +697,24 @@ impl PixiControl {
         }
     }
 
+    /// Returns a [`BuildBuilder`]. To execute the command and await the result
+    /// call `.await` on the return value.
+    pub fn build(&self) -> BuildBuilder {
+        BuildBuilder {
+            args: build::Args {
+                backend_override: Default::default(),
+                config_cli: Default::default(),
+                lock_and_install_config: Default::default(),
+                target_platform: rattler_conda_types::Platform::current(),
+                build_platform: rattler_conda_types::Platform::current(),
+                output_dir: PathBuf::from("."),
+                build_dir: None,
+                clean: false,
+                path: Some(self.manifest_path()),
+            },
+        }
+    }
+
     pub fn tasks(&self) -> TasksControl {
         TasksControl { pixi: self }
     }
