@@ -57,7 +57,7 @@ all = ["recursive-optional-groups[np]"]
 docs = ["sphinx"]
 test = ["recursive-optional-groups[np]", "pytest", {{include-group = "docs"}}]
 
-[tool.pixi.project]
+[tool.pixi.workspace]
 channels = ["{channel_url}"]
 platforms = ["{platform_str}"]
 
@@ -413,6 +413,108 @@ async fn test_allow_insecure_host() {
     pixi.update_lock_file().await.unwrap();
 }
 
+#[tokio::test]
+#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+async fn test_tls_no_verify_with_pypi_dependencies() {
+    let pixi = PixiControl::from_manifest(&format!(
+        r#"
+        [project]
+        name = "pypi-tls-test"
+        platforms = ["{platform}"]
+        channels = ["https://prefix.dev/conda-forge"]
+
+        [dependencies]
+        python = "~=3.12.0"
+
+        [pypi-dependencies]
+        sh = "*"
+
+        [pypi-options]
+        extra-index-urls = ["https://expired.badssl.com/"]"#,
+        platform = Platform::current(),
+    ))
+    .unwrap();
+
+    // First verify that it fails with SSL errors when tls-no-verify is not set
+    assert!(
+        pixi.update_lock_file().await.is_err(),
+        "should fail with SSL error when tls-no-verify is not enabled"
+    );
+
+    // Now set tls-no-verify = true in the project config
+    let config_path = pixi.workspace().unwrap().pixi_dir().join("config.toml");
+    fs_err::create_dir_all(config_path.parent().unwrap()).unwrap();
+    let mut file = File::create(config_path).unwrap();
+    file.write_all(
+        r#"
+        tls-no-verify = true"#
+            .as_bytes(),
+    )
+    .unwrap();
+
+    // With tls-no-verify = true, this should now succeed or fail for non-SSL reasons
+    let result = pixi.update_lock_file().await;
+
+    // The test should succeed because tls-no-verify bypasses SSL verification
+    // If it fails, it should not be due to SSL certificate issues
+    match result {
+        Ok(_) => {
+            // Success - TLS verification was bypassed
+        }
+        Err(e) => {
+            let error_msg = format!("{e:?}");
+            // If it fails, it should NOT be due to SSL/TLS certificate issues
+            assert!(
+                !error_msg.to_lowercase().contains("certificate")
+                    && !error_msg.to_lowercase().contains("ssl")
+                    && !error_msg.to_lowercase().contains("tls"),
+                "Error should not be SSL/TLS related when tls-no-verify is enabled. Got: {error_msg}"
+            );
+        }
+    }
+}
+
+#[tokio::test]
+#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+async fn test_tls_verify_still_fails_without_config() {
+    let pixi = PixiControl::from_manifest(&format!(
+        r#"
+        [project]
+        name = "pypi-tls-verify-test"
+        platforms = ["{platform}"]
+        channels = ["https://prefix.dev/conda-forge"]
+
+        [dependencies]
+        python = "~=3.12.0"
+
+        [pypi-dependencies]
+        sh = "*"
+
+        [pypi-options]
+        extra-index-urls = ["https://expired.badssl.com/"]"#,
+        platform = Platform::current(),
+    ))
+    .unwrap();
+
+    // Without tls-no-verify, this should fail with SSL errors
+    let result = pixi.update_lock_file().await;
+    assert!(
+        result.is_err(),
+        "should fail with SSL error when tls-no-verify is not enabled"
+    );
+
+    let error = result.unwrap_err();
+    let error_msg = format!("{error:?}");
+    // The error should be SSL/TLS related
+    assert!(
+        error_msg.to_lowercase().contains("certificate")
+            || error_msg.to_lowercase().contains("ssl")
+            || error_msg.to_lowercase().contains("tls")
+            || error_msg.contains("expired.badssl.com"),
+        "Error should be SSL/TLS related. Got: {error_msg}"
+    );
+}
+
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_indexes_are_passed_when_solving_build_pypi_dependencies() {
@@ -447,7 +549,7 @@ async fn test_indexes_are_passed_when_solving_build_pypi_dependencies() {
 
 
 
-        [tool.pixi.project]
+        [tool.pixi.workspace]
         channels = ["https://prefix.dev/conda-forge"]
         platforms = ["{platform}"]
 
@@ -554,7 +656,7 @@ async fn test_index_strategy_respected_for_build_dependencies() {
         ]
         build-backend = "uv_build"
 
-        [tool.pixi.project]
+        [tool.pixi.workspace]
         channels = ["https://prefix.dev/conda-forge"]
         platforms = ["{platform}"]
 
@@ -771,3 +873,125 @@ async fn test_uv_index_correctly_parsed() {
             .contains(&simple.index_path().display().to_string())
     );
 }
+
+/// Tests that prerelease-mode = "allow" allows pre-release versions to be resolved.
+/// Without this setting, the resolver would skip pre-releases unless explicitly requested.
+#[tokio::test]
+async fn test_prerelease_mode_allow() {
+    setup_tracing();
+
+    // Build a local simple index with both a stable and prerelease version
+    let simple = PyPIDatabase::new()
+        .with(PyPIPackage::new("testpkg", "1.0.0"))
+        .with(PyPIPackage::new("testpkg", "2.0.0a1")) // Pre-release version
+        .into_simple_index()
+        .expect("failed to create local simple index");
+
+    let platform = Platform::current();
+
+    let mut package_db = PackageDatabase::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+    let channel_url = channel.url();
+
+    // With prerelease-mode = "allow", the resolver should pick the pre-release 2.0.0a1
+    let pixi = PixiControl::from_manifest(&format!(
+        r#"
+        [project]
+        name = "prerelease-test"
+        platforms = ["{platform}"]
+        channels = ["{channel_url}"]
+
+        [dependencies]
+        python = "==3.12.0"
+
+        [pypi-dependencies]
+        testpkg = "*"
+
+        [pypi-options]
+        index-url = "{index_url}"
+        prerelease-mode = "allow"
+        "#,
+        platform = platform,
+        channel_url = channel_url,
+        index_url = simple.index_url(),
+    ))
+    .unwrap();
+
+    let lock_file = pixi.update_lock_file().await.unwrap();
+
+    // With prerelease-mode = "allow", we should get the pre-release version 2.0.0a1
+    // because it's the highest version available
+    let locked_version = lock_file
+        .get_pypi_package_version("default", platform, "testpkg")
+        .expect("testpkg should be in lock file");
+    assert_eq!(
+        locked_version.to_string(),
+        "2.0.0a1",
+        "With prerelease-mode = 'allow', the pre-release version should be selected"
+    );
+}
+
+/// Tests that prerelease-mode = "disallow" prevents pre-release versions from being resolved.
+#[tokio::test]
+async fn test_prerelease_mode_disallow() {
+    setup_tracing();
+
+    // Build a local simple index with both a stable and prerelease version
+    let simple = PyPIDatabase::new()
+        .with(PyPIPackage::new("testpkg", "1.0.0"))
+        .with(PyPIPackage::new("testpkg", "2.0.0a1")) // Pre-release version
+        .into_simple_index()
+        .expect("failed to create local simple index");
+
+    let platform = Platform::current();
+
+    let mut package_db = PackageDatabase::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+    let channel_url = channel.url();
+
+    // With prerelease-mode = "disallow", the resolver should pick the stable 1.0.0
+    let pixi = PixiControl::from_manifest(&format!(
+        r#"
+        [project]
+        name = "prerelease-test"
+        platforms = ["{platform}"]
+        channels = ["{channel_url}"]
+
+        [dependencies]
+        python = "==3.12.0"
+
+        [pypi-dependencies]
+        testpkg = "*"
+
+        [pypi-options]
+        index-url = "{index_url}"
+        prerelease-mode = "disallow"
+        "#,
+        platform = platform,
+        channel_url = channel_url,
+        index_url = simple.index_url(),
+    ))
+    .unwrap();
+
+    let lock_file = pixi.update_lock_file().await.unwrap();
+
+    // With prerelease-mode = "disallow", we should get the stable version 1.0.0
+    let locked_version = lock_file
+        .get_pypi_package_version("default", platform, "testpkg")
+        .expect("testpkg should be in lock file");
+    assert_eq!(
+        locked_version.to_string(),
+        "1.0.0",
+        "With prerelease-mode = 'disallow', the stable version should be selected"
+    );
+}
