@@ -465,18 +465,14 @@ async fn test_we_record_not_present_package_as_purl_for_custom_mapping() {
 
     let package = packages.pop().unwrap();
 
-    let first_purl = package
-        .package_record
-        .purls
-        .as_ref()
-        .and_then(BTreeSet::first)
-        .unwrap();
-
-    // we verify that even if this name is not present in our mapping
-    // we record a purl anyways. Because we make the assumption
-    // that it's a pypi package
-    assert_eq!(first_purl.name(), "pixi-something-new");
-    assert!(first_purl.qualifiers().is_empty());
+    // With custom mapping, packages not in the mapping should NOT get purls
+    // This verifies that custom mapping is exclusive - only packages explicitly
+    // mapped should be considered as pypi packages
+    assert!(
+        package.package_record.purls.is_none()
+            || package.package_record.purls.as_ref().unwrap().is_empty(),
+        "pixi-something-new should not have purls when not in custom mapping"
+    );
 }
 
 #[tokio::test]
@@ -788,3 +784,72 @@ async fn test_disabled_mapping() {
     assert_eq!(boltons_first_purl.name(), "boltons");
     assert!(boltons_first_purl.qualifiers().is_empty());
 }
+
+#[tokio::test]
+async fn test_custom_mapping_ignores_backwards_compatibility() {
+    setup_tracing();
+
+    // Create a custom mapping file that only includes specific packages
+    let temp_dir = TempDir::new().unwrap();
+    let mapping_file = temp_dir.path().join("map.json");
+    fs_err::write(&mapping_file, r#"{}"#).unwrap();
+
+    let pixi = PixiControl::from_manifest(&format!(
+        r#"
+    [workspace]
+    name = "test-custom-mapping"
+    channels = ["https://prefix.dev/conda-forge"]
+    platforms = ["linux-64"]
+    conda-pypi-map = {{ "https://prefix.dev/conda-forge" = "{}" }}
+
+    [dependencies]
+    boltons = "*"
+
+    [pypi-dependencies]
+    boltons = "*"
+    "#,
+        mapping_file
+            .to_str()
+            .unwrap()
+            .to_string()
+            .replace("\\", "/")
+    ))
+    .unwrap();
+
+    // Lock the project (this triggers the amend_purls logic)
+    pixi.lock().await.unwrap();
+
+    // Get the lock file
+    let lock = pixi.lock_file().await.unwrap();
+    let environment = lock.environment(DEFAULT_ENVIRONMENT_NAME).unwrap();
+    let conda_packages = environment.conda_packages(Platform::Linux64).unwrap();
+
+    // Collect conda packages to a vector so we can iterate over them
+    let conda_packages: Vec<_> = conda_packages.collect();
+
+    // Find boltons in conda packages
+    let boltons_package = conda_packages
+        .iter()
+        .find(|pkg| match pkg {
+            rattler_lock::CondaPackageData::Binary(binary) => {
+                binary.package_record.name.as_source() == "boltons"
+            }
+            _ => panic!("All packagees should be binary"),
+        })
+        .expect("boltons should be present in conda packages");
+
+    // The issue: boltons should NOT have purls when using custom mapping
+    // because it's not specified in our custom mapping
+    // But due to backwards compatibility logic, it gets purls anyway
+    let purls = match boltons_package {
+        rattler_lock::CondaPackageData::Binary(binary) => &binary.package_record.purls,
+        _ => panic!("All packages should be binary"),
+    };
+
+    if let Some(purls) = purls {
+        assert!(
+            purls.is_empty(),
+            "boltons should not have purls when not specified in custom conda-pypi-map"
+        );
+    }
+}
