@@ -9,6 +9,7 @@ use ordermap::OrderMap;
 use pixi_build_type_conversions::{to_project_model_v1, to_target_selector_v1};
 use pixi_build_types::{ProjectModelV1, TargetSelectorV1};
 use pixi_config::Config;
+use pixi_consts::consts::{RATTLER_BUILD_DIRS, RATTLER_BUILD_FILE_NAMES, ROS_BACKEND_FILE_NAMES};
 use pixi_manifest::{
     DiscoveryStart, ExplicitManifestError, PackageManifest, PrioritizedChannel, WithProvenance,
     WorkspaceDiscoverer, WorkspaceDiscoveryError, WorkspaceManifest,
@@ -23,10 +24,6 @@ use crate::{
     backend_spec::{CommandSpec, EnvironmentSpec, JsonRpcBackendSpec},
 };
 
-const RATTLER_BUILD_FILE_NAMES: [&str; 2] = ["recipe.yaml", "recipe.yml"];
-const RATTLER_BUILD_DIRS: [&str; 2] = ["", "recipe"];
-const ROS_BACKEND_FILE_NAMES: [&str; 1] = ["package.xml"];
-
 /// Describes a backend discovered for a given source location.
 #[derive(Debug, Clone)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize))]
@@ -49,7 +46,7 @@ pub struct BackendInitializationParams {
     pub workspace_root: PathBuf,
 
     /// The location of the source code.
-    pub source: Option<SourceLocationSpec>,
+    pub build_source: Option<SourceLocationSpec>,
 
     /// The anchor for relative paths to the location of the source code.
     pub source_anchor: PathBuf,
@@ -118,9 +115,12 @@ pub enum DiscoveryError {
 
     #[error("the source directory '{0}', does not contain a supported manifest")]
     #[diagnostic(help(
-        "Ensure that the source directory contains a valid pixi.toml or recipe.yaml file."
+        "Ensure that the source directory contains a valid pixi.toml, pyproject.toml, recipe.yaml, package.xml or mojoproject.toml file."
     ))]
     FailedToDiscover(String),
+
+    #[error("the manifest path '{0}', does not have a parent directory")]
+    NoParentDir(PathBuf),
 }
 
 impl DiscoveredBackend {
@@ -202,7 +202,7 @@ impl DiscoveredBackend {
             backend_spec: BackendSpec::JsonRpc(JsonRpcBackendSpec::default_rattler_build(channels)),
             init_params: BackendInitializationParams {
                 workspace_root: source_dir.clone(),
-                source: None,
+                build_source: None,
                 source_anchor: source_dir,
                 manifest_path: recipe_absolute_path,
                 project_model: None,
@@ -273,7 +273,7 @@ impl DiscoveredBackend {
             init_params: BackendInitializationParams {
                 workspace_root,
                 manifest_path: provenance.path.clone(),
-                source: build_system.source,
+                build_source: build_system.source,
                 source_anchor: provenance
                     .path
                     .parent()
@@ -327,14 +327,9 @@ impl DiscoveredBackend {
             ));
         };
 
-        Self::from_package_and_workspace(
-            // source_path,
-            &package_manifest,
-            &manifests.workspace,
-            channel_config,
-        )
-        .map_err(DiscoveryError::SpecConversionError)
-        .map(Some)
+        Self::from_package_and_workspace(&package_manifest, &manifests.workspace, channel_config)
+            .map_err(DiscoveryError::SpecConversionError)
+            .map(Some)
     }
 
     /// Try to discover a rattler build recipe in the repository.
@@ -374,9 +369,14 @@ impl DiscoveredBackend {
             backend_spec: BackendSpec::JsonRpc(JsonRpcBackendSpec::default_ros_build(channels)),
             init_params: BackendInitializationParams {
                 workspace_root: source_dir.clone(),
-                source: None,
+                build_source: None,
                 source_anchor: source_dir,
-                manifest_path: package_xml_absolute_path,
+                manifest_path: package_xml_absolute_path
+                    .parent()
+                    .ok_or(DiscoveryError::NoParentDir(
+                        package_xml_absolute_path.clone(),
+                    ))?
+                    .to_path_buf(),
                 project_model: Some(ProjectModelV1::default()),
                 configuration: None,
                 target_configuration: None,
