@@ -167,7 +167,7 @@ impl Display for EnvironmentInfo {
                 .collect::<Vec<_>>()
                 .join("\n");
 
-            writeln!(f, "{}", indented)?;
+            writeln!(f, "{indented}")?;
         }
 
         if !self.tasks.is_empty() {
@@ -297,7 +297,7 @@ impl Display for Info {
         // Pixi global information
         if let Some(gi) = self.global_info.as_ref() {
             writeln!(f, "\n{}", bold.apply_to("Global\n------------").cyan())?;
-            write!(f, "{}", gi)?;
+            write!(f, "{gi}")?;
         }
 
         // Workspace information
@@ -331,7 +331,7 @@ impl Display for Info {
                 bold.apply_to("Environments\n------------").cyan()
             )?;
             for e in &self.environments_info {
-                writeln!(f, "{}", e)?;
+                writeln!(f, "{e}")?;
             }
         }
 
@@ -504,7 +504,7 @@ pub async fn execute(args: Args) -> miette::Result<()> {
         })
         .into_diagnostic()?;
     } else {
-        writeln!(std::io::stdout(), "{}", info)
+        writeln!(std::io::stdout(), "{info}")
             .map_err(|e| {
                 if e.kind() == std::io::ErrorKind::BrokenPipe {
                     std::process::exit(0);
