@@ -1,11 +1,15 @@
+use std::io::Write;
+
 use fancy_display::FancyDisplay;
 use itertools::Itertools;
+use miette::IntoDiagnostic;
 use pixi_consts::consts;
 use pixi_core::Workspace;
 use pixi_manifest::HasFeaturesIter;
 
 pub async fn execute(workspace: Workspace) -> miette::Result<()> {
-    println!(
+    writeln!(
+        std::io::stdout(),
         "Environments:\n{}",
         workspace
             .environments()
@@ -23,7 +27,13 @@ pub async fn execute(workspace: Workspace) -> miette::Result<()> {
                     "".to_string()
                 }
             )))
-    );
+    )
+    .inspect_err(|e| {
+        if e.kind() == std::io::ErrorKind::BrokenPipe {
+            std::process::exit(0);
+        }
+    })
+    .into_diagnostic()?;
 
     Ok(())
 }
