@@ -3,6 +3,7 @@ use std::{path::PathBuf, sync::Arc};
 use pixi_build_frontend::BackendOverride;
 use pixi_git::resolver::GitResolver;
 use pixi_glob::GlobHashCache;
+use pixi_url::resolver::UrlResolver;
 use rattler::package_cache::PackageCache;
 use rattler_conda_types::{GenericVirtualPackage, Platform};
 use rattler_networking::LazyClient;
@@ -25,6 +26,7 @@ pub struct CommandDispatcherBuilder {
     root_dir: Option<PathBuf>,
     reporter: Option<Box<dyn Reporter>>,
     git_resolver: Option<GitResolver>,
+    url_resolver: Option<UrlResolver>,
     download_client: Option<LazyClient>,
     cache_dirs: Option<CacheDirs>,
     build_backend_overrides: BackendOverride,
@@ -76,6 +78,14 @@ impl CommandDispatcherBuilder {
         }
     }
 
+    /// Sets the url resolver used to fetch archives.
+    pub fn with_url_resolver(self, resolver: UrlResolver) -> Self {
+        Self {
+            url_resolver: Some(resolver),
+            ..self
+        }
+    }
+
     /// Sets the root directory for resolving relative paths.
     pub fn with_root_dir(self, root_dir: PathBuf) -> Self {
         Self {
@@ -153,6 +163,7 @@ impl CommandDispatcherBuilder {
         });
 
         let git_resolver = self.git_resolver.unwrap_or_default();
+        let url_resolver = self.url_resolver.unwrap_or_default();
         let source_metadata_cache = SourceMetadataCache::new(cache_dirs.source_metadata());
         let build_cache = BuildCache::new(cache_dirs.source_builds());
         let tool_platform = self.tool_platform.unwrap_or_else(|| {
@@ -171,6 +182,7 @@ impl CommandDispatcherBuilder {
             build_cache,
             root_dir,
             git_resolver,
+            url_resolver,
             cache_dirs,
             download_client,
             build_backend_overrides: self.build_backend_overrides,
