@@ -21,6 +21,7 @@ use crate::{
         CommandDispatcherContext, CommandDispatcherData, ForegroundMessage,
         InstallPixiEnvironmentId, InstantiatedToolEnvId, SolveCondaEnvironmentId,
         SolvePixiEnvironmentId, SourceBuildCacheStatusId, SourceBuildId, SourceMetadataId,
+        url::{UrlCheckout, UrlError},
     },
     executor::ExecutorFutures,
     install_pixi::InstallPixiEnvironmentError,
@@ -32,6 +33,7 @@ use futures::{StreamExt, future::LocalBoxFuture};
 use itertools::Itertools;
 use pixi_git::{GitError, resolver::RepositoryReference, source::Fetch};
 use pixi_record::PixiRecord;
+use pixi_spec::UrlSpec;
 use tokio::sync::{mpsc, oneshot};
 use tokio_util::sync::CancellationToken;
 
@@ -45,6 +47,7 @@ mod solve_pixi;
 mod source_build;
 mod source_build_cache_status;
 mod source_metadata;
+mod url;
 
 /// Runs the command_dispatcher background task
 pub(crate) struct CommandDispatcherProcessor {
@@ -112,6 +115,10 @@ pub(crate) struct CommandDispatcherProcessor {
     /// out.
     git_checkouts: HashMap<RepositoryReference, PendingGitCheckout>,
 
+    /// Url checkouts in the process of being checked out, or already
+    /// checked out.
+    url_checkouts: HashMap<::url::Url, PendingUrlCheckout>,
+
     /// Source builds that are currently being processed.
     source_build:
         HashMap<SourceBuildId, PendingDeduplicatingTask<SourceBuildResult, SourceBuildError>>,
@@ -164,6 +171,7 @@ enum TaskResult {
         BoxedDispatcherResult<Arc<SourceMetadata>, SourceMetadataError>,
     ),
     GitCheckedOut(RepositoryReference, BoxedDispatcherResult<Fetch, GitError>),
+    UrlCheckedOut(::url::Url, BoxedDispatcherResult<UrlCheckout, UrlError>),
     InstallPixiEnvironment(
         InstallPixiEnvironmentId,
         BoxedDispatcherResult<InstallPixiEnvironmentResult, InstallPixiEnvironmentError>,
@@ -201,6 +209,23 @@ enum PendingGitCheckout {
     Errored,
 }
 
+// We store spec here to double-check that hashes are correct.
+struct PendingUrlWaiter {
+    spec: UrlSpec,
+    tx: oneshot::Sender<Result<UrlCheckout, UrlError>>,
+}
+
+enum PendingUrlCheckout {
+    /// The checkout is still ongoing.
+    Pending(Option<reporter::UrlCheckoutId>, Vec<PendingUrlWaiter>),
+
+    /// The URL was checked out and the result is available.
+    CheckedOut(UrlCheckout),
+
+    /// A previous attempt failed
+    Errored,
+}
+
 /// Information about a pending conda environment solve. This is used by the
 /// background task to keep track of which command_dispatcher is awaiting the
 /// result.
@@ -321,6 +346,7 @@ impl CommandDispatcherProcessor {
                 instantiated_tool_envs_reporters: HashMap::default(),
                 instantiated_tool_cache_keys: HashMap::default(),
                 git_checkouts: HashMap::default(),
+                url_checkouts: HashMap::default(),
                 source_build: HashMap::default(),
                 source_build_reporters: HashMap::default(),
                 source_build_ids: HashMap::default(),
@@ -382,6 +408,7 @@ impl CommandDispatcherProcessor {
             }
             ForegroundMessage::BuildBackendMetadata(task) => self.on_build_backend_metadata(task),
             ForegroundMessage::GitCheckout(task) => self.on_checkout_git(task),
+            ForegroundMessage::UrlCheckout(task) => self.on_checkout_url(task),
             ForegroundMessage::SourceBuild(task) => self.on_source_build(task),
             ForegroundMessage::QuerySourceBuildCache(task) => {
                 self.on_source_build_cache_status(task)
@@ -411,6 +438,7 @@ impl CommandDispatcherProcessor {
                 self.on_build_backend_metadata_result(id, *result)
             }
             TaskResult::GitCheckedOut(url, result) => self.on_git_checked_out(url, *result),
+            TaskResult::UrlCheckedOut(url, result) => self.on_url_checked_out(url, *result),
             TaskResult::InstantiateToolEnv(id, result) => {
                 self.on_instantiate_tool_environment_result(id, *result)
             }
