@@ -7,7 +7,7 @@ use std::{
 use futures::{FutureExt, StreamExt};
 use miette::Diagnostic;
 use pixi_build_discovery::EnabledProtocols;
-use pixi_record::PinnedSourceSpec;
+use pixi_record::{PinnedSourceSpec, VariantValue};
 use pixi_spec::{SourceAnchor, SourceSpec};
 use rattler_conda_types::{ChannelConfig, ChannelUrl, MatchSpec, ParseStrictness};
 use thiserror::Error;
@@ -27,8 +27,9 @@ pub struct SourceMetadataCollector {
     channels: Vec<ChannelUrl>,
     build_environment: BuildEnvironment,
     enabled_protocols: EnabledProtocols,
-    variants: Option<BTreeMap<String, Vec<String>>>,
+    variant_configuration: Option<BTreeMap<String, Vec<VariantValue>>>,
     variant_files: Option<Vec<PathBuf>>,
+    preferred_build_sources: BTreeMap<rattler_conda_types::PackageName, PinnedSourceSpec>,
 }
 
 #[derive(Default)]
@@ -68,14 +69,16 @@ pub enum CollectSourceMetadataError {
 }
 
 impl SourceMetadataCollector {
+    #[allow(clippy::too_many_arguments)]
     pub fn new(
         command_queue: CommandDispatcher,
         channel_urls: Vec<ChannelUrl>,
         channel_config: ChannelConfig,
         build_environment: BuildEnvironment,
-        variants: Option<BTreeMap<String, Vec<String>>>,
+        variant_configuration: Option<BTreeMap<String, Vec<VariantValue>>>,
         variant_files: Option<Vec<PathBuf>>,
         enabled_protocols: EnabledProtocols,
+        preferred_build_sources: BTreeMap<rattler_conda_types::PackageName, PinnedSourceSpec>,
     ) -> Self {
         Self {
             command_queue,
@@ -83,8 +86,9 @@ impl SourceMetadataCollector {
             build_environment,
             enabled_protocols,
             channel_config,
-            variants,
+            variant_configuration,
             variant_files,
+            preferred_build_sources,
         }
     }
 
@@ -123,17 +127,29 @@ impl SourceMetadataCollector {
             // Process transitive dependencies
             for record in &source_metadata.records {
                 chain.push(record.package_record.name.clone());
-                let anchor = SourceAnchor::from(SourceSpec::from(record.source.clone()));
+                let anchor = SourceAnchor::from(SourceSpec::from(record.manifest_source.clone()));
                 for depend in &record.package_record.depends {
                     if let Ok(spec) = MatchSpec::from_str(depend, ParseStrictness::Lenient) {
-                        if let Some((name, source_spec)) = spec.name.as_ref().and_then(|name| {
-                            record
-                                .sources
-                                .get(name.as_normalized())
-                                .map(|source_spec| (name.clone(), source_spec.clone()))
-                        }) {
+                        if let Some((name, source_spec)) =
+                            spec.name.as_ref().and_then(|name_matcher| {
+                                let name = name_matcher
+                                    .as_exact()
+                                    .expect("depends can only contain exact package names");
+                                record
+                                    .sources
+                                    .get(name.as_normalized())
+                                    .map(|source_spec| (name.clone(), source_spec.clone()))
+                            })
+                        {
                             // We encountered a transitive source dependency.
-                            specs.push((name, anchor.resolve(source_spec), chain.clone()));
+                            let resolved_location = anchor.resolve(source_spec.location);
+                            specs.push((
+                                name,
+                                SourceSpec {
+                                    location: resolved_location,
+                                },
+                                chain.clone(),
+                            ));
                         } else {
                             // We encountered a transitive dependency that is not a source
                             result.transitive_dependencies.push(spec);
@@ -160,10 +176,14 @@ impl SourceMetadataCollector {
     > {
         tracing::trace!("Collecting source metadata for {name:#?}");
 
-        // Get the source for the particular package.
-        let source = self
+        // Determine if we should override the build_source pin for this package.
+        let preferred_build_source = self.preferred_build_sources.get(&name).cloned();
+
+        // Always checkout the manifest-defined source location (root), discovery
+        // will pick build_source; we only pass preferred locations.
+        let manifest_source_checkout = self
             .command_queue
-            .pin_and_checkout(spec)
+            .pin_and_checkout(spec.location)
             .await
             .map_err(|err| CollectSourceMetadataError::SourceCheckoutError {
                 name: name.as_source().to_string(),
@@ -177,11 +197,12 @@ impl SourceMetadataCollector {
             .source_metadata(SourceMetadataSpec {
                 package: name.clone(),
                 backend_metadata: BuildBackendMetadataSpec {
-                    source: source.pinned,
+                    manifest_source: manifest_source_checkout.pinned,
+                    preferred_build_source,
                     channel_config: self.channel_config.clone(),
                     channels: self.channels.clone(),
                     build_environment: self.build_environment.clone(),
-                    variants: self.variants.clone(),
+                    variant_configuration: self.variant_configuration.clone(),
                     variant_files: self.variant_files.clone(),
                     enabled_protocols: self.enabled_protocols.clone(),
                 },
@@ -221,7 +242,7 @@ impl SourceMetadataCollector {
                         source_metadata.skipped_packages.clone(),
                     ),
                     name,
-                    pinned_source: Box::new(source_metadata.source.clone()),
+                    pinned_source: Box::new(source_metadata.source.manifest_source().clone()),
                 },
             ));
         }
