@@ -1,13 +1,16 @@
 mod cycle;
 
-use std::{collections::HashMap, sync::Arc};
+use std::{
+    collections::{BTreeMap, HashMap},
+    sync::Arc,
+};
 
 pub use cycle::{Cycle, CycleEnvironment};
 use futures::TryStreamExt;
 use itertools::{Either, Itertools};
 use miette::Diagnostic;
 use pixi_build_types::procedures::conda_outputs::CondaOutput;
-use pixi_record::{InputHash, PinnedSourceSpec, PixiRecord, SourceRecord};
+use pixi_record::{InputHash, PixiRecord, SourceRecord};
 use pixi_spec::{BinarySpec, PixiSpec, SourceAnchor, SourceSpec, SpecConversionError};
 use pixi_spec_containers::DependencyMap;
 use rattler_conda_types::{
@@ -23,7 +26,7 @@ use crate::{
     CommandDispatcherError, CommandDispatcherErrorResultExt, PixiEnvironmentSpec,
     SolvePixiEnvironmentError,
     build::{
-        Dependencies, DependenciesError, PixiRunExports, conversion,
+        Dependencies, DependenciesError, PixiRunExports, SourceCodeLocation, conversion,
         source_metadata_cache::MetadataKind,
     },
     executor::ExecutorFutures,
@@ -41,9 +44,8 @@ pub struct SourceMetadataSpec {
 /// The result of building a particular source record.
 #[derive(Debug, Clone)]
 pub struct SourceMetadata {
-    /// Information about the source checkout that was used to build the
-    /// package.
-    pub source: PinnedSourceSpec,
+    /// Manifest and optional build source location for this metadata.
+    pub source: SourceCodeLocation,
 
     /// All the source records for this particular package.
     pub records: Vec<SourceRecord>,
@@ -57,7 +59,8 @@ impl SourceMetadataSpec {
         skip_all,
         name = "source-metadata",
         fields(
-            source= %self.backend_metadata.source,
+            manifest_source= %self.backend_metadata.manifest_source,
+            preferred_build_source=?self.backend_metadata.preferred_build_source,
             name = %self.package.as_source(),
             platform = %self.backend_metadata.build_environment.host_platform,
         )
@@ -77,16 +80,18 @@ impl SourceMetadataSpec {
 
         match &build_backend_metadata.metadata.metadata {
             MetadataKind::GetMetadata { packages } => {
+                let source_location = build_backend_metadata.source.clone();
                 // Convert the metadata to source records.
                 let records = conversion::package_metadata_to_source_records(
-                    &build_backend_metadata.source,
+                    source_location.manifest_source(),
+                    source_location.build_source(),
                     packages,
                     &self.package,
                     &build_backend_metadata.metadata.input_hash,
                 );
 
                 Ok(SourceMetadata {
-                    source: build_backend_metadata.source.clone(),
+                    source: source_location,
                     records,
                     // As the GetMetadata kind returns all records at once and we don't solve them we can skip this.
                     skipped_packages: Default::default(),
@@ -95,6 +100,7 @@ impl SourceMetadataSpec {
             MetadataKind::Outputs { outputs } => {
                 let mut skipped_packages = vec![];
                 let mut futures = ExecutorFutures::new(command_dispatcher.executor());
+                let source_location = build_backend_metadata.source.clone();
                 for output in outputs {
                     if output.metadata.name != self.package {
                         skipped_packages.push(output.metadata.name.clone());
@@ -104,13 +110,13 @@ impl SourceMetadataSpec {
                         &command_dispatcher,
                         output,
                         build_backend_metadata.metadata.input_hash.clone(),
-                        build_backend_metadata.source.clone(),
+                        source_location.clone(),
                         reporter.clone(),
                     ));
                 }
 
                 Ok(SourceMetadata {
-                    source: build_backend_metadata.source.clone(),
+                    source: source_location,
                     records: futures.try_collect().await?,
                     skipped_packages,
                 })
@@ -123,15 +129,18 @@ impl SourceMetadataSpec {
         command_dispatcher: &CommandDispatcher,
         output: &CondaOutput,
         input_hash: Option<InputHash>,
-        source: PinnedSourceSpec,
+        source: SourceCodeLocation,
         reporter: Option<Arc<dyn RunExportsReporter>>,
     ) -> Result<SourceRecord, CommandDispatcherError<SourceMetadataError>> {
-        let source_anchor = SourceAnchor::from(SourceSpec::from(source.clone()));
+        let manifest_source = source.manifest_source().clone();
+        let build_source = source.build_source().cloned();
+        let source_anchor = SourceAnchor::from(SourceSpec::from(manifest_source.clone()));
 
         // Solve the build environment for the output.
         let build_dependencies = output
             .build_dependencies
             .as_ref()
+            // TODO(tim): we need to check if this works for out-of-tree builds with source dependencies in the out-of-tree, this might be incorrectly anchored
             .map(|deps| Dependencies::new(deps, Some(source_anchor.clone())))
             .transpose()
             .map_err(SourceMetadataError::from)
@@ -237,14 +246,14 @@ impl SourceMetadataSpec {
                     };
                     Ok(MatchSpec::from_nameless(
                         source.to_nameless_match_spec(),
-                        Some(name.clone()),
+                        Some(name.clone().into()),
                     ))
                 }
                 Either::Right(binary) => {
                     let spec = binary
                         .try_into_nameless_match_spec(&self.backend_metadata.channel_config)
                         .map_err(SourceMetadataError::SpecConversionError)?;
-                    Ok(MatchSpec::from_nameless(spec, Some(name.clone())))
+                    Ok(MatchSpec::from_nameless(spec, Some(name.clone().into())))
                 }
             }
         };
@@ -272,7 +281,7 @@ impl SourceMetadataSpec {
                     let nameless_spec = spec
                         .try_into_nameless_match_spec(&self.backend_metadata.channel_config)
                         .map_err(SourceMetadataError::SpecConversionError)?;
-                    Ok(MatchSpec::from_nameless(nameless_spec, Some(name)).to_string())
+                    Ok(MatchSpec::from_nameless(nameless_spec, Some(name.into())).to_string())
                 })
                 .collect::<Result<Vec<_>, SourceMetadataError>>()
                 .map_err(CommandDispatcherError::Failed)
@@ -340,12 +349,21 @@ impl SourceMetadataSpec {
                 // These are not important at this point.
                 experimental_extra_depends: Default::default(),
             },
-            source,
+            manifest_source,
             input_hash,
+            build_source,
             sources: sources
                 .into_iter()
                 .map(|(name, source)| (name.as_source().to_string(), source))
                 .collect(),
+            variants: Some(
+                output
+                    .metadata
+                    .variant
+                    .iter()
+                    .map(|(k, v)| (k.clone(), pixi_record::VariantValue::from(v.clone())))
+                    .collect(),
+            ),
         })
     }
 
@@ -360,6 +378,12 @@ impl SourceMetadataSpec {
         if dependencies.dependencies.is_empty() {
             return Ok(vec![]);
         }
+        let preferred_build_source = self
+            .backend_metadata
+            .preferred_build_source
+            .as_ref()
+            .map(|pinned| BTreeMap::from([(pkg_name.clone(), pinned.clone())]))
+            .unwrap_or_default();
         match command_dispatcher
             .solve_pixi_environment(PixiEnvironmentSpec {
                 name: Some(format!("{} ({})", pkg_name.as_source(), env_type)),
@@ -380,9 +404,10 @@ impl SourceMetadataSpec {
                 channel_priority: Default::default(),
                 exclude_newer: None,
                 channel_config: self.backend_metadata.channel_config.clone(),
-                variants: self.backend_metadata.variants.clone(),
+                variant_configuration: self.backend_metadata.variant_configuration.clone(),
                 variant_files: self.backend_metadata.variant_files.clone(),
                 enabled_protocols: self.backend_metadata.enabled_protocols.clone(),
+                preferred_build_source,
             })
             .await
         {
@@ -428,7 +453,7 @@ impl PackageRecordDependencies {
             .map(|(name, spec)| {
                 Ok(MatchSpec::from_nameless(
                     spec.value.try_into_nameless_match_spec(channel_config)?,
-                    Some(name),
+                    Some(name.into()),
                 ))
             })
             .map_ok(|spec| spec.to_string())
@@ -440,7 +465,7 @@ impl PackageRecordDependencies {
                 Either::Left(source) => {
                     depends.push(
                         MatchSpec {
-                            name: Some(name.clone()),
+                            name: Some(name.clone().into()),
                             ..MatchSpec::default()
                         }
                         .to_string(),
@@ -449,7 +474,7 @@ impl PackageRecordDependencies {
                 }
                 Either::Right(binary) => {
                     if let Ok(spec) = binary.try_into_nameless_match_spec(channel_config) {
-                        depends.push(MatchSpec::from_nameless(spec, Some(name)).to_string());
+                        depends.push(MatchSpec::from_nameless(spec, Some(name.into())).to_string());
                     }
                 }
             }
