@@ -9,24 +9,28 @@ use std::{
 };
 
 use event_reporter::EventReporter;
+use fs_err as fs;
 use itertools::Itertools;
 use pixi_build_backend_passthrough::PassthroughBackend;
 use pixi_build_frontend::{BackendOverride, InMemoryOverriddenBackends};
 use pixi_command_dispatcher::{
-    BuildEnvironment, CacheDirs, CommandDispatcher, Executor, InstallPixiEnvironmentSpec,
-    InstantiateToolEnvironmentSpec, PackageIdentifier, PixiEnvironmentSpec,
-    SourceBuildCacheStatusSpec,
+    BuildEnvironment, CacheDirs, CommandDispatcher, CommandDispatcherError, Executor,
+    InstallPixiEnvironmentSpec, InstantiateToolEnvironmentSpec, PackageIdentifier,
+    PixiEnvironmentSpec, SourceBuildCacheStatusSpec, build::SourceCodeLocation,
 };
 use pixi_config::default_channel_config;
-use pixi_record::PinnedPathSpec;
-use pixi_spec::{GitReference, GitSpec, PathSpec, PixiSpec};
+use pixi_record::{PinnedPathSpec, PinnedSourceSpec};
+use pixi_spec::{GitReference, GitSpec, PathSpec, PixiSpec, UrlSpec};
 use pixi_spec_containers::DependencyMap;
 use pixi_test_utils::format_diagnostic;
+use pixi_url::UrlError;
 use rattler_conda_types::{
     ChannelUrl, GenericVirtualPackage, PackageName, Platform, VersionSpec, VersionWithSource,
     prefix::Prefix,
 };
+use rattler_digest::{Sha256, Sha256Hash, digest::Digest};
 use rattler_virtual_packages::{VirtualPackageOverrides, VirtualPackages};
+use tempfile::TempDir;
 use url::Url;
 
 use crate::{event_reporter::Event, event_tree::EventTree};
@@ -69,6 +73,28 @@ fn default_build_environment() -> BuildEnvironment {
     BuildEnvironment::simple(tool_platform, tool_virtual_packages)
 }
 
+fn dummy_sha() -> Sha256Hash {
+    Sha256::digest(b"pixi-url-cache-test")
+}
+
+fn prepare_cached_checkout(cache_root: &Path, sha: Sha256Hash) -> PathBuf {
+    let checkout_dir = cache_root.join("checkouts").join(format!("{sha:x}"));
+    fs::create_dir_all(&checkout_dir).unwrap();
+    fs::write(checkout_dir.join("payload.txt"), "cached contents").unwrap();
+    fs::write(checkout_dir.join(".pixi-url-ready"), "ready").unwrap();
+    checkout_dir
+}
+
+fn hello_world_archive() -> PathBuf {
+    Path::new(env!("CARGO_MANIFEST_DIR")).join("../../tests/data/url/hello_world.zip")
+}
+
+fn file_url_for_test(tempdir: &TempDir, name: &str) -> Url {
+    let path = tempdir.path().join(name);
+    fs::copy(hello_world_archive(), &path).unwrap();
+    Url::from_file_path(&path).unwrap()
+}
+
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 pub async fn simple_test() {
@@ -127,7 +153,7 @@ pub async fn simple_test() {
                     .into(),
             ],
             channel_config: default_channel_config(),
-            variants: None,
+            variant_configuration: None,
             variant_files: None,
             enabled_protocols: Default::default(),
         })
@@ -563,10 +589,13 @@ async fn source_build_cache_status_clear_works() {
 
     let spec = SourceBuildCacheStatusSpec {
         package: pkg,
-        source: PinnedPathSpec {
-            path: tmp_dir.path().to_string_lossy().into_owned().into(),
-        }
-        .into(),
+        source: SourceCodeLocation::new(
+            PinnedPathSpec {
+                path: tmp_dir.path().to_string_lossy().into_owned().into(),
+            }
+            .into(),
+            None,
+        ),
         channels: Vec::<ChannelUrl>::new(),
         build_environment: build_env,
         channel_config: default_channel_config(),
@@ -763,3 +792,112 @@ pub async fn test_force_rebuild() {
         "Expected no packages to be queued for rebuild"
     );
 }
+
+#[tokio::test]
+pub async fn pin_and_checkout_url_reuses_cached_checkout() {
+    let tempdir = tempfile::tempdir().unwrap();
+    let cache_dirs = CacheDirs::new(tempdir.path().join("pixi-cache"));
+    let url_cache_root = cache_dirs.url();
+
+    let sha = dummy_sha();
+    let checkout_dir = prepare_cached_checkout(&url_cache_root, sha);
+
+    let dispatcher = CommandDispatcher::builder()
+        .with_cache_dirs(cache_dirs)
+        .with_executor(Executor::Serial)
+        .finish();
+
+    // Since we have the same expected hash we expect to return existing archive.
+    let spec = UrlSpec {
+        url: "https://example.com/archive.tar.gz".parse().unwrap(),
+        md5: None,
+        sha256: Some(sha),
+    };
+
+    let checkout = dispatcher
+        .pin_and_checkout_url(spec.clone())
+        .await
+        .expect("url checkout should succeed");
+
+    assert_eq!(checkout.path, checkout_dir);
+    match checkout.pinned {
+        PinnedSourceSpec::Url(pinned) => {
+            assert_eq!(pinned.url, spec.url);
+            assert_eq!(pinned.sha256, sha);
+        }
+        other => panic!("expected url pinned spec, got {other:?}"),
+    }
+}
+
+#[tokio::test]
+pub async fn pin_and_checkout_url_reports_sha_mismatch_from_concurrent_request() {
+    let tempdir = tempfile::tempdir().unwrap();
+    let cache_dirs = CacheDirs::new(tempdir.path().join("pixi-cache"));
+    let archive = tempfile::tempdir().unwrap();
+    let url = file_url_for_test(&archive, "archive.zip");
+
+    let dispatcher = CommandDispatcher::builder()
+        .with_cache_dirs(cache_dirs)
+        .with_executor(Executor::Concurrent)
+        .finish();
+
+    let good_spec = UrlSpec {
+        url: url.clone(),
+        md5: None,
+        sha256: None,
+    };
+    let bad_spec = UrlSpec {
+        url,
+        md5: None,
+        sha256: Some(Sha256::digest(b"pixi-url-bad-sha")),
+    };
+
+    let (good, bad) = tokio::join!(
+        dispatcher.checkout_url(good_spec),
+        dispatcher.checkout_url(bad_spec),
+    );
+
+    assert!(good.is_ok());
+    assert!(matches!(
+        bad,
+        Err(CommandDispatcherError::Failed(
+            UrlError::Sha256Mismatch { .. }
+        ))
+    ));
+}
+
+#[tokio::test]
+pub async fn pin_and_checkout_url_validates_cached_results() {
+    let tempdir = tempfile::tempdir().unwrap();
+    let cache_dirs = CacheDirs::new(tempdir.path().join("pixi-cache"));
+    let archive = tempfile::tempdir().unwrap();
+    let url = file_url_for_test(&archive, "archive.zip");
+
+    let dispatcher = CommandDispatcher::builder()
+        .with_cache_dirs(cache_dirs)
+        .with_executor(Executor::Serial)
+        .finish();
+
+    let spec = UrlSpec {
+        url: url.clone(),
+        md5: None,
+        sha256: None,
+    };
+
+    dispatcher
+        .checkout_url(spec.clone())
+        .await
+        .expect("initial download succeeds");
+
+    let bad_spec = UrlSpec {
+        url: url.clone(),
+        md5: None,
+        sha256: Some(Sha256::digest(b"pixi-url-bad-cache")),
+    };
+
+    let err = dispatcher.checkout_url(bad_spec).await.unwrap_err();
+    assert!(matches!(
+        err,
+        CommandDispatcherError::Failed(UrlError::Sha256Mismatch { .. })
+    ));
+}
