@@ -18,17 +18,18 @@ use indicatif::ProgressBar;
 use itertools::{Either, Itertools};
 use miette::{Context, IntoDiagnostic};
 use pixi_consts::consts;
+use pixi_git::git::GitReference;
 use pixi_manifest::{
     EnvironmentName, SolveStrategy, SystemRequirements, pypi::pypi_options::PypiOptions,
 };
 use pixi_pypi_spec::PixiPypiSpec;
-use pixi_record::PixiRecord;
+use pixi_record::{LockedGitUrl, PixiRecord};
 use pixi_reporters::{UvReporter, UvReporterOptions};
 use pixi_uv_conversions::{
-    ConversionError, as_uv_req, convert_uv_requirements_to_pep508, into_pinned_git_spec,
-    pypi_options_to_build_options, pypi_options_to_index_locations, to_exclude_newer,
-    to_index_strategy, to_normalize, to_requirements, to_uv_normalize, to_uv_version,
-    to_version_specifiers,
+    ConversionError, as_uv_req, configure_insecure_hosts_for_tls_bypass,
+    convert_uv_requirements_to_pep508, into_pinned_git_spec, pypi_options_to_build_options,
+    pypi_options_to_index_locations, to_exclude_newer, to_index_strategy, to_normalize,
+    to_prerelease_mode, to_requirements, to_uv_normalize, to_uv_version, to_version_specifiers,
 };
 use pypi_modifiers::{
     pypi_marker_env::determine_marker_environment,
@@ -40,15 +41,20 @@ use rattler_lock::{
 };
 use typed_path::Utf8TypedPathBuf;
 use url::Url;
-use uv_client::{Connectivity, FlatIndexClient, RegistryClient, RegistryClientBuilder};
-use uv_configuration::{ConfigSettings, Constraints, Overrides};
+use uv_client::{
+    BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClient, RegistryClientBuilder,
+};
+use uv_configuration::{Constraints, Overrides};
 use uv_distribution::DistributionDatabase;
 use uv_distribution_types::{
-    BuiltDist, DependencyMetadata, Diagnostic, Dist, FileLocation, HashPolicy, IndexCapabilities,
-    IndexUrl, Name, RequirementSource, RequiresPython, Resolution, ResolvedDist, SourceDist,
-    ToUrlError,
+    BuiltDist, ConfigSettings, DependencyMetadata, Diagnostic, Dist, FileLocation, HashPolicy,
+    IndexCapabilities, IndexUrl, Name, RequirementSource, RequiresPython, Resolution, ResolvedDist,
+    SourceDist, ToUrlError,
 };
+use uv_git_types::GitUrl;
+use uv_pep508::VerbatimUrl;
 use uv_pypi_types::{Conflicts, HashAlgorithm, HashDigests};
+use uv_redacted::DisplaySafeUrl;
 use uv_requirements::LookaheadResolver;
 use uv_resolver::{
     AllowedYanks, DefaultResolverProvider, FlatIndex, InMemoryIndex, Manifest, Options, Preference,
@@ -223,6 +229,10 @@ pub enum SolveError {
     BuildDispatchPanic { message: String },
     #[error("unexpected panic during PyPI resolution: {message}")]
     GeneralPanic { message: String },
+
+    #[error(transparent)]
+    #[diagnostic(transparent)]
+    LookAhead(Box<dyn miette::Diagnostic + Send + Sync + 'static>),
 }
 
 /// Creates a custom `SolveError` from a `ResolveError`.
@@ -323,20 +333,20 @@ pub async fn resolve_pypi(
     if !conda_python_packages.is_empty() {
         tracing::info!(
             "the following python packages are assumed to be installed by conda: {conda_python_packages}",
-            conda_python_packages =
-                conda_python_packages
-                    .values()
-                    .format_with(", ", |(_, p), f| f(&format_args!(
-                        "{name} {version}",
-                        name = &p.name.as_source(),
-                        version = &p.version
-                    )))
+            conda_python_packages = conda_python_packages
+                .values()
+                .format_with(", ", |(_, p), f| f(&format_args!(
+                    "{name} {version}",
+                    name = &p.name.as_source(),
+                    version = &p.version
+                )))
+                .to_string()
         );
     } else {
         tracing::info!("there are no python packages installed by conda");
     }
 
-    let requirements = dependencies
+    let mut requirements = dependencies
         .into_iter()
         .flat_map(|(name, req)| {
             req.into_iter()
@@ -397,15 +407,26 @@ pub async fn resolve_pypi(
 
     // TODO: create a cached registry client per index_url set?
     let index_strategy = to_index_strategy(pypi_options.index_strategy.as_ref());
-    let mut uv_client_builder = RegistryClientBuilder::new(context.cache.clone())
-        .allow_insecure_host(context.allow_insecure_host.clone())
-        .index_locations(&index_locations)
-        .index_strategy(index_strategy)
+
+    // Configure insecure hosts for TLS verification bypass
+    let allow_insecure_hosts = configure_insecure_hosts_for_tls_bypass(
+        context.allow_insecure_host.clone(),
+        context.tls_no_verify,
+        &index_locations,
+    );
+
+    let base_client_builder = BaseClientBuilder::default()
+        .allow_insecure_host(allow_insecure_hosts)
         .markers(&marker_environment)
         .keyring(context.keyring_provider)
         .connectivity(Connectivity::Online)
         .extra_middleware(context.extra_middleware.clone());
 
+    let mut uv_client_builder =
+        RegistryClientBuilder::new(base_client_builder, context.cache.clone())
+            .index_locations(index_locations.clone())
+            .index_strategy(index_strategy);
+
     for p in &context.proxies {
         uv_client_builder = uv_client_builder.proxy(p.clone())
     }
@@ -435,8 +456,6 @@ pub async fn resolve_pypi(
                 .collect::<Result<Vec<_>, _>>()
         }).transpose()?.unwrap_or_default();
 
-    let overrides = Overrides::from_requirements(dependency_overrides);
-
     // Resolve the flat indexes from `--find-links`.
     // In UV 0.7.8, we need to fetch flat index entries from the index locations
     let flat_index_client = FlatIndexClient::new(
@@ -465,12 +484,15 @@ pub async fn resolve_pypi(
         SolveStrategy::LowestDirect => ResolutionMode::LowestDirect,
     };
 
+    let prerelease_mode = to_prerelease_mode(pypi_options.prerelease_mode.as_ref());
+
     // Hi maintainers! For anyone coming here, if you expose any additional `uv`
     // options, similar to `index_strategy`, make sure to include them in this
     // struct as well instead of relying on the default. Otherwise there be
     // panics.
     let options = Options {
         resolution_mode,
+        prerelease_mode,
         index_strategy,
         build_options: build_options.clone(),
         exclude_newer: exclude_newer.map(to_exclude_newer).unwrap_or_default(),
@@ -552,6 +574,15 @@ pub async fn resolve_pypi(
         Conversion(#[from] ConversionError),
         #[error(transparent)]
         Preference(#[from] PreferenceError),
+
+        #[error(transparent)]
+        OidParse(#[from] uv_git_types::OidParseError),
+
+        #[error(transparent)]
+        GitUrlParse(#[from] uv_git_types::GitUrlParseError),
+
+        #[error("{0}")]
+        Other(miette::ErrReport),
     }
 
     // Create preferences from the locked pypi packages
@@ -574,13 +605,69 @@ pub async fn resolve_pypi(
                 origin: None,
             };
 
-            let named = uv_requirements_txt::RequirementsTxtRequirement::Named(requirement);
-            let entry = uv_requirements_txt::RequirementEntry {
-                requirement: named,
-                hashes: Default::default(),
-            };
+            // When iterating over locked packages,
+            // instead of adding git requirements as preferences
+            // we enrich previous defined requirements in the `requirements` list
+            // as they have been pinned to a precise commit
+            // This will help the resolver to pick the commit that we already have locked
+            // instead of updating to a newer commit that also matches the requirement.
+            if let Some(location) = package_data.location.as_url() {
+                // now check if it's a git url
+                if LockedGitUrl::is_locked_git_url(location) {
+                    // we need to parse back `LockedGitUrl` in order to get the `PinnedGitSpec`
+                    // then we will precise commit to set for the `GitUrl`
+                    // that will be used in the `RequirementSource::Git` below
+                    let git_locked_url = LockedGitUrl::from(location.clone());
+                    let pinned_git_spec = git_locked_url
+                        .to_pinned_git_spec()
+                        .map_err(PixiPreferencesError::Other)?;
+                    // we need to create VerbatimUrl from the original location
+                    let verbatim_url = VerbatimUrl::from(location.clone());
 
-            Ok(Preference::from_entry(entry)?)
+                    // but the display safe url should come from the `PinnedGitSpec` url
+                    // which don't have anymore git+ prefix
+                    let display_safe = DisplaySafeUrl::from(pinned_git_spec.git.clone());
+
+                    let git_oid =
+                        uv_git_types::GitOid::from_str(&pinned_git_spec.source.commit.to_string())?;
+
+                    let git_url = GitUrl::try_from(display_safe)?.with_precise(git_oid);
+
+                    let constraint_source = RequirementSource::Git {
+                        git: git_url,
+                        subdirectory: None,
+                        url: verbatim_url,
+                    };
+
+                    // find this requirements in dependencies and skip adding it as preference
+                    let req_from_dep = requirements.iter_mut().find(|r| r.name == requirement.name);
+                    if let Some(req) = req_from_dep {
+                        // we need to update the requirement source in the requirements list
+                        // to use the precise git commit
+                        // only if the requirements do not already have a source set with something specific
+                        if let RequirementSource::Git { git, .. } = &req.source {
+                                // only update if the git url does not already have a precise commit
+                                if git.precise().is_none() && !GitReference::looks_like_commit_hash(git.reference().as_rev()) {
+                                    tracing::debug!(
+                                        "updating requirement source to precise git commit for requirement: {:?}",
+                                        &req
+                                    );
+                                    req.source = constraint_source.clone();
+                                }
+
+                            }
+                    }
+                }
+                Ok(None)
+            } else {
+                let named = uv_requirements_txt::RequirementsTxtRequirement::Named(requirement);
+                let entry = uv_requirements_txt::RequirementEntry {
+                    requirement: named,
+                    hashes: Default::default(),
+                };
+
+                Ok(Preference::from_entry(entry)?)
+            }
         })
         .filter_map(|pref| pref.transpose())
         .collect::<Result<Vec<_>, PixiPreferencesError>>()
@@ -590,6 +677,8 @@ pub async fn resolve_pypi(
 
     let constraints = Constraints::from_requirements(constraints.iter().cloned());
 
+    let overrides = Overrides::from_requirements(dependency_overrides);
+
     // Wrap the resolution in panic catching to handle conda prefix initialization failures
     // This includes both lookahead resolution and main resolution since both use lazy_build_dispatch
     let package_requests = Rc::new(RefCell::new(Default::default()));
@@ -614,9 +703,7 @@ pub async fn resolve_pypi(
         .resolve(&resolver_env)
         .await
         .into_diagnostic()
-        .map_err(|e| SolveError::GeneralPanic {
-            message: format!("Failed to do lookahead resolution: {e}"),
-        })?;
+        .map_err(|e| SolveError::LookAhead(e.into()))?;
 
         // Move manifest and provider setup inside catch_unwind
         let manifest = Manifest::new(
@@ -1118,6 +1205,57 @@ mod tests {
         assert_eq!(path.as_str(), "./b/c");
     }
 
+    #[test]
+    fn test_tls_no_verify_host_conversion() {
+        use pixi_uv_conversions::to_uv_trusted_host;
+        // Test the logic for converting hosts to trusted hosts when tls_no_verify is enabled
+        let test_hosts = vec![
+            "pypi.org",
+            "test-index.example.com",
+            "another-index.example.org",
+        ];
+
+        let mut allow_insecure_hosts = vec![];
+        let tls_no_verify = true;
+
+        if tls_no_verify {
+            for host in &test_hosts {
+                if let Ok(trusted_host) = to_uv_trusted_host(host) {
+                    allow_insecure_hosts.push(trusted_host);
+                }
+            }
+        }
+
+        assert_eq!(allow_insecure_hosts.len(), 3);
+
+        let host_names: Vec<String> = allow_insecure_hosts.iter().map(|h| h.to_string()).collect();
+
+        assert!(host_names.contains(&"pypi.org".to_string()));
+        assert!(host_names.contains(&"test-index.example.com".to_string()));
+        assert!(host_names.contains(&"another-index.example.org".to_string()));
+    }
+
+    #[test]
+    fn test_tls_verify_enabled_preserves_empty_list() {
+        use pixi_uv_conversions::to_uv_trusted_host;
+        // Test that when tls_no_verify is false, no hosts are added
+        let test_hosts = vec!["pypi.org", "test-index.example.com"];
+
+        let mut allow_insecure_hosts = vec![];
+        let tls_no_verify = false;
+
+        if tls_no_verify {
+            // This should not execute
+            for host in &test_hosts {
+                if let Ok(trusted_host) = to_uv_trusted_host(host) {
+                    allow_insecure_hosts.push(trusted_host);
+                }
+            }
+        }
+
+        assert_eq!(allow_insecure_hosts.len(), 0);
+    }
+
     // In this case we want to make the path relative to the project_root or lock
     // file path
     #[cfg(target_os = "windows")]
