@@ -461,7 +461,7 @@ mod tests {
             .default_environment()
             .task(&"foo".into(), None)
             .unwrap()
-            .as_single_command(None)
+            .as_single_command(&pixi_manifest::task::TaskRenderContext::default())
             .unwrap()
             .unwrap();
 
@@ -471,7 +471,10 @@ mod tests {
             .default_environment()
             .task(&"foo".into(), Some(Platform::Linux64))
             .unwrap()
-            .as_single_command(None)
+            .as_single_command(&pixi_manifest::task::TaskRenderContext {
+                platform: Platform::Linux64,
+                ..pixi_manifest::task::TaskRenderContext::default()
+            })
             .unwrap()
             .unwrap();
 
@@ -1026,4 +1029,95 @@ mod tests {
             pixi_manifest::SolveStrategy::Highest
         );
     }
+
+    /// Test that combining channel priorities from multiple features
+    /// results in a ChannelPriorityCombinationError if the priorities conflict.
+    #[test]
+    fn test_channel_priority_compatibility() {
+        use crate::workspace::grouped_environment::GroupedEnvironment;
+
+        // First part - priorities are compatible
+        {
+            let contents = r#"
+            [project]
+            name = "test"
+            platforms = ["linux-64"]
+            channels = ["conda-forge"]
+            channel-priority = "disabled"
+
+            [feature.feat1]
+            channel-priority = "disabled"  # Is ok as it's the same as the default
+
+            [environments]
+            test = ["feat1"]
+            "#;
+
+            let workspace = Workspace::from_str(Path::new("pixi.toml"), contents).unwrap();
+            let env = workspace.environment("test").unwrap();
+            let grouped_env = GroupedEnvironment::from(env);
+
+            // This should not return an error because both features have the same channel-priority
+            let result = grouped_env.channel_priority();
+            assert!(
+                result.is_ok(),
+                "Channel priorities were expected to be compatible"
+            );
+        }
+        // Second part, priorities conflict
+        {
+            let contents = r#"
+            [project]
+            name = "test"
+            platforms = ["linux-64"]
+            channels = ["conda-forge"]
+            channel-priority = "disabled"
+
+            [feature.feat1]
+            channel-priority = "strict"  # Conflicts with the default
+
+            [environments]
+            test = ["feat1"]
+            "#;
+
+            let workspace = Workspace::from_str(Path::new("pixi.toml"), contents).unwrap();
+            let env = workspace.environment("test").unwrap();
+            let grouped_env = GroupedEnvironment::from(env);
+
+            // This should return an error because the features have conflicting channel-priorities
+            let result = grouped_env.channel_priority();
+            assert!(
+                result.is_err(),
+                "Channel priorities were expected to be incompatible"
+            );
+        }
+        // Third part, there is a default priority, but the feature doesn't have a priority set.
+        {
+            let contents = r#"
+            [project]
+            name = "test"
+            platforms = ["linux-64"]
+            channels = ["conda-forge"]
+            channel-priority = "disabled"
+
+            # Adding a dependency, just so the feature has at least some data
+            [feature.feat1.dependencies]
+            python = ">=3.13"
+
+            [environments]
+            test = ["feat1"]
+            "#;
+
+            let workspace = Workspace::from_str(Path::new("pixi.toml"), contents).unwrap();
+            let env = workspace.environment("test").unwrap();
+            let grouped_env = GroupedEnvironment::from(env);
+
+            // This should not return an error because the default feature sets the priority
+            let result = grouped_env.channel_priority();
+            assert_eq!(
+                result.unwrap(),
+                Some(pixi_manifest::ChannelPriority::Disabled),
+                "Channel priorities were expected to be compatible"
+            );
+        }
+    }
 }
