@@ -89,7 +89,7 @@ pub const TRAMPOLINE_BIN_NAME: &str = "trampoline_bin";
 /// Returns the file name of the executable
 pub(crate) fn file_name(exposed_name: &ExposedName) -> String {
     if cfg!(target_os = "windows") {
-        format!("{}.exe", exposed_name)
+        format!("{exposed_name}.exe")
     } else {
         exposed_name.to_string()
     }
