@@ -12,6 +12,7 @@ use crate::workspace::JINJA_ENV;
 use indexmap::IndexMap;
 use itertools::Itertools;
 use miette::{Diagnostic, SourceSpan};
+use rattler_conda_types::Platform;
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 use toml_edit::{Array, InlineTable, Item, Table, Value};
@@ -19,7 +20,7 @@ use toml_edit::{Array, InlineTable, Item, Table, Value};
 use crate::EnvironmentName;
 
 /// Represents a task name
-#[derive(Debug, Clone, Serialize, Eq, PartialEq, Hash, Ord, PartialOrd)]
+#[derive(Debug, Clone, Serialize, Eq, PartialEq, Hash, Ord, PartialOrd, Deserialize)]
 pub struct TaskName(String);
 
 impl TaskName {
@@ -46,14 +47,14 @@ impl From<String> for TaskName {
 }
 
 /// A task dependency with optional args
-#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
 pub struct Dependency {
     pub task_name: TaskName,
     pub args: Option<Vec<DependencyArg>>,
     pub environment: Option<EnvironmentName>,
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
 pub enum DependencyArg {
     Positional(TemplateString),
     Named(String, TemplateString),
@@ -81,7 +82,7 @@ impl Dependency {
     }
     pub fn render_args(
         &self,
-        args: Option<&ArgValues>,
+        context: &TaskRenderContext,
     ) -> Result<Option<Vec<TypedDependencyArg>>, TemplateStringError> {
         match &self.args {
             Some(task_args) => {
@@ -89,10 +90,11 @@ impl Dependency {
                 for arg in task_args {
                     match arg {
                         DependencyArg::Positional(val) => {
-                            result.push(TypedDependencyArg::Positional(val.render(args)?));
+                            result.push(TypedDependencyArg::Positional(val.render(context)?));
                         }
                         DependencyArg::Named(key, val) => {
-                            result.push(TypedDependencyArg::Named(key.clone(), val.render(args)?));
+                            result
+                                .push(TypedDependencyArg::Named(key.clone(), val.render(context)?));
                         }
                     }
                 }
@@ -142,18 +144,18 @@ pub enum TypedDependencyArg {
 impl TypedDependency {
     pub fn from_dependency(
         dependency: &Dependency,
-        args: Option<&ArgValues>,
+        context: &TaskRenderContext,
     ) -> Result<Self, TemplateStringError> {
         Ok(TypedDependency {
             task_name: dependency.task_name.clone(),
-            args: dependency.render_args(args)?,
+            args: dependency.render_args(context)?,
             environment: dependency.environment.clone(),
         })
     }
 }
 
 /// Represents different types of scripts
-#[derive(Debug, Clone, Serialize)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub enum Task {
     Plain(TemplateString),
     Execute(Box<Execute>),
@@ -200,15 +202,15 @@ impl Task {
     /// Returns the command to execute as a single string.
     pub fn as_single_command(
         &self,
-        args_values: Option<&ArgValues>,
+        context: &TaskRenderContext,
     ) -> Result<Option<Cow<str>>, TemplateStringError> {
         match self {
-            Task::Plain(str) => match str.render(args_values) {
+            Task::Plain(str) => match str.render(context) {
                 Ok(rendered) => Ok(Some(Cow::Owned(rendered))),
                 Err(e) => Err(e),
             },
-            Task::Custom(custom) => custom.cmd.as_single(args_values),
-            Task::Execute(exe) => exe.cmd.as_single(args_values),
+            Task::Custom(custom) => custom.cmd.as_single(context),
+            Task::Execute(exe) => exe.cmd.as_single(context),
             Task::Alias(_) => Ok(None),
         }
     }
@@ -303,14 +305,14 @@ impl GlobPatterns {
         GlobPatterns(patterns)
     }
 
-    /// Renders the glob patterns using the provided arguments
+    /// Renders the glob patterns using the provided context
     pub fn render(
         &self,
-        args: Option<&ArgValues>,
+        context: &TaskRenderContext,
     ) -> Result<Vec<RenderedString>, TemplateStringError> {
         self.0
             .iter()
-            .map(|i| i.render(args).map(RenderedString::from))
+            .map(|i| i.render(context).map(RenderedString::from))
             .collect::<Result<Vec<RenderedString>, _>>()
     }
 }
@@ -324,7 +326,7 @@ impl Deref for GlobPatterns {
 }
 
 /// A command script executes a single command from the environment
-#[derive(Debug, Clone, Serialize)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Execute {
     /// A list of arguments, the first argument denotes the command to run. When
     /// deserializing both an array of strings and a single string are
@@ -365,7 +367,7 @@ impl From<Execute> for Task {
     }
 }
 
-#[derive(Debug, Clone, Eq, Hash, PartialEq, Serialize)]
+#[derive(Debug, Clone, Eq, Hash, PartialEq, Serialize, Deserialize)]
 pub struct ArgName(String);
 
 impl FromStr for ArgName {
@@ -388,7 +390,7 @@ impl ArgName {
     }
 }
 
-#[derive(Debug, Clone, Eq, Hash, PartialEq, Serialize)]
+#[derive(Debug, Clone, Eq, Hash, PartialEq, Serialize, Deserialize)]
 pub struct TaskArg {
     /// The name of the argument
     pub name: ArgName,
@@ -409,7 +411,7 @@ impl std::str::FromStr for TaskArg {
 }
 
 /// A custom command script executes a single command in the environment
-#[derive(Debug, Clone, Serialize)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Custom {
     /// A list of arguments, the first argument denotes the command to run. When
     /// deserializing both an array of strings and a single string are
@@ -439,6 +441,117 @@ impl Display for TypedArg {
     }
 }
 
+// Static default environment name for use in Default impl
+static DEFAULT_ENV: EnvironmentName = EnvironmentName::Default;
+
+/// Context for rendering task templates with MiniJinja.
+///
+/// This struct contains system-provided variables that are automatically
+/// available in task templates, in addition to user-provided arguments.
+#[derive(Debug, Clone)]
+pub struct TaskRenderContext<'a> {
+    /// The platform for which the task is being rendered.
+    /// This corresponds to the environment's best platform.
+    pub platform: Platform,
+
+    /// The name of the environment for which the task is being rendered.
+    pub environment_name: &'a EnvironmentName,
+
+    /// The absolute path to the manifest file.
+    pub manifest_path: Option<&'a Path>,
+
+    /// The arguments to use for rendering.
+    pub args: Option<&'a ArgValues>,
+}
+
+impl Default for TaskRenderContext<'_> {
+    fn default() -> Self {
+        Self {
+            platform: Platform::current(),
+            environment_name: &DEFAULT_ENV,
+            manifest_path: None,
+            args: None,
+        }
+    }
+}
+
+impl<'a> TaskRenderContext<'a> {
+    /// Builds a MiniJinja context value from this render context.
+    ///
+    /// The context always includes the pixi system variables.
+    /// User arguments are added when TypedArgs are provided.
+    pub fn to_jinja_context(&self) -> minijinja::Value {
+        // Build the context map with user arguments if available
+        let mut context_map: HashMap<String, minijinja::Value> =
+            if let Some(ArgValues::TypedArgs(args)) = self.args {
+                args.iter()
+                    .map(|arg| (arg.name.clone(), minijinja::Value::from(arg.value.as_str())))
+                    .collect()
+            } else {
+                HashMap::new()
+            };
+
+        // Create the pixi object with system-provided variables
+        let mut pixi_vars: HashMap<String, minijinja::Value> = HashMap::new();
+
+        // Add platform as a string
+        pixi_vars.insert(
+            "platform".to_string(),
+            minijinja::Value::from(self.platform.to_string()),
+        );
+
+        // Add platform detection boolean flags
+        pixi_vars.insert(
+            "is_win".to_string(),
+            minijinja::Value::from(self.platform.is_windows()),
+        );
+        pixi_vars.insert(
+            "is_unix".to_string(),
+            minijinja::Value::from(self.platform.is_unix()),
+        );
+        pixi_vars.insert(
+            "is_linux".to_string(),
+            minijinja::Value::from(self.platform.is_linux()),
+        );
+        pixi_vars.insert(
+            "is_osx".to_string(),
+            minijinja::Value::from(self.platform.is_osx()),
+        );
+
+        // Add environment object
+        let mut env_vars: HashMap<String, minijinja::Value> = HashMap::new();
+        env_vars.insert(
+            "name".to_string(),
+            minijinja::Value::from(self.environment_name.as_str()),
+        );
+        pixi_vars.insert(
+            "environment".to_string(),
+            minijinja::Value::from_serialize(&env_vars),
+        );
+
+        // Add manifest path if available
+        if let Some(path) = self.manifest_path {
+            pixi_vars.insert(
+                "manifest_path".to_string(),
+                minijinja::Value::from(path.display().to_string()),
+            );
+        }
+
+        // Add pixi version
+        pixi_vars.insert(
+            "version".to_string(),
+            minijinja::Value::from(pixi_consts::consts::PIXI_VERSION),
+        );
+
+        context_map.insert(
+            "pixi".to_string(),
+            minijinja::Value::from_serialize(&pixi_vars),
+        );
+
+        minijinja::Value::from_serialize(&context_map)
+    }
+}
+
 /// A string that contains placeholders to be rendered using the `minijinja` templating engine.
 #[derive(Debug, Clone, Eq, PartialEq, Serialize, Hash, Deserialize)]
 pub struct TemplateString(String);
@@ -460,26 +573,14 @@ impl TemplateString {
         TemplateString(value)
     }
 
-    pub fn render(&self, args: Option<&ArgValues>) -> Result<String, TemplateStringError> {
-        // Only perform MiniJinja rendering when typed args are provided.
-        // For free-form args or no args, return the source verbatim to avoid
-        // interpreting arbitrary strings as templates.
-        if let Some(ArgValues::TypedArgs(args)) = args {
-            let args_map: HashMap<&str, &str> = args
-                .iter()
-                .map(|arg| (arg.name.as_str(), arg.value.as_str()))
-                .collect();
-            let context = minijinja::Value::from_serialize(&args_map);
-
-            JINJA_ENV
-                .render_str(&self.0, context)
-                .map_err(|e| TemplateStringError {
-                    src: self.0.clone(),
-                    err_span: e.range().unwrap_or_default().into(),
-                })
-        } else {
-            Ok(self.0.clone())
-        }
+    pub fn render(&self, context: &TaskRenderContext) -> Result<String, TemplateStringError> {
+        let jinja_context = context.to_jinja_context();
+        JINJA_ENV
+            .render_str(&self.0, jinja_context)
+            .map_err(|e| TemplateStringError {
+                src: self.0.clone(),
+                err_span: e.range().unwrap_or_default().into(),
+            })
     }
 
     pub fn source(&self) -> &str {
@@ -571,7 +672,7 @@ impl TemplateStringError {
     }
 }
 
-#[derive(Debug, Clone, Serialize)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub enum CmdArgs {
     Single(TemplateString),
     Multiple(Vec<TemplateString>),
@@ -593,14 +694,14 @@ impl CmdArgs {
     /// Returns a single string representation of the command arguments.
     pub fn as_single(
         &self,
-        args_values: Option<&ArgValues>,
+        context: &TaskRenderContext,
     ) -> Result<Option<Cow<str>>, TemplateStringError> {
         match self {
-            CmdArgs::Single(cmd) => Ok(Some(Cow::Owned(cmd.render(args_values)?))),
+            CmdArgs::Single(cmd) => Ok(Some(Cow::Owned(cmd.render(context)?))),
             CmdArgs::Multiple(args) => {
                 let mut rendered_args = Vec::new();
                 for arg in args {
-                    let rendered = arg.render(args_values)?;
+                    let rendered = arg.render(context)?;
                     rendered_args.push(quote(&rendered).to_string());
                 }
                 Ok(Some(Cow::Owned(rendered_args.join(" "))))
@@ -611,15 +712,15 @@ impl CmdArgs {
     /// Returns a single string representation of the command arguments.
     pub fn into_single(
         self,
-        args_values: Option<&ArgValues>,
+        context: &TaskRenderContext,
     ) -> Result<Option<String>, TemplateStringError> {
         match self {
-            CmdArgs::Single(cmd) => cmd.render(args_values).map(Some),
+            CmdArgs::Single(cmd) => cmd.render(context).map(Some),
             CmdArgs::Multiple(args) => {
                 let rendered_args = args
                     .iter()
                     .map(|arg| {
-                        Ok(match arg.render(args_values) {
+                        Ok(match arg.render(context) {
                             Ok(rendered) => quote(&rendered).to_string(),
                             Err(e) => return Err(e),
                         })
@@ -640,7 +741,7 @@ impl CmdArgs {
     }
 }
 
-#[derive(Debug, Clone, Serialize)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Alias {
     /// A list of commands that should be run before this one
     pub depends_on: Vec<Dependency>,
@@ -894,12 +995,13 @@ impl From<Task> for Item {
 #[cfg(test)]
 mod tests {
     use insta::assert_snapshot;
+    use rattler_conda_types::Platform;
 
     use crate::task::{Alias, Dependency, DependencyArg, Task};
 
     use super::quote;
 
-    use super::{ArgValues, TemplateString, TypedArg};
+    use super::{ArgValues, TaskRenderContext, TemplateString, TypedArg};
 
     #[test]
     fn test_quote() {
@@ -933,17 +1035,79 @@ mod tests {
     }
 
     #[test]
-    fn test_template_string_no_render_without_typed_args() {
-        let t = TemplateString::from("echo {{ foo }}");
-        // No args -> should not render, return verbatim string
-        let rendered = t.render(None).expect("should not error without typed args");
-        assert_eq!(rendered, "echo {{ foo }}");
+    fn test_template_string_pixi_vars_always_available() {
+        // pixi variables should always be available, even without typed args
+        let t = TemplateString::from("echo {{ pixi.platform }}");
 
-        // Free-form args -> should not render
+        // No args -> pixi.platform still works
+        let context = TaskRenderContext::default();
         let rendered = t
-            .render(Some(&ArgValues::FreeFormArgs(vec!["bar".into()])))
-            .expect("should not error with free-form args");
-        assert_eq!(rendered, "echo {{ foo }}");
+            .render(&context)
+            .expect("pixi.platform should be available without args");
+        assert_eq!(rendered, format!("echo {}", Platform::current()));
+
+        // Free-form args -> pixi.platform still works
+        let free_args = ArgValues::FreeFormArgs(vec!["bar".into()]);
+        let context = TaskRenderContext {
+            args: Some(&free_args),
+            ..TaskRenderContext::default()
+        };
+        let rendered = t
+            .render(&context)
+            .expect("pixi.platform should be available with free-form args");
+        assert_eq!(rendered, format!("echo {}", Platform::current()));
+    }
+
+    #[test]
+    fn test_template_string_undefined_var_errors() {
+        // Undefined user variables should cause an error
+        let t = TemplateString::from("echo {{ foo }}");
+        let context = TaskRenderContext::default();
+        let result = t.render(&context);
+        assert!(result.is_err(), "undefined variable should cause error");
+    }
+
+    #[test]
+    fn test_template_string_pixi_variables() {
+        // Test all pixi system variables
+        use crate::EnvironmentName;
+        use std::path::PathBuf;
+        use std::str::FromStr;
+
+        let env_name = EnvironmentName::from_str("test-env").unwrap();
+        let manifest_path = PathBuf::from("/tmp/pixi.toml");
+        let args = ArgValues::TypedArgs(vec![]);
+
+        let context = TaskRenderContext {
+            platform: Platform::Linux64,
+            environment_name: &env_name,
+            manifest_path: Some(&manifest_path),
+            args: Some(&args),
+        };
+
+        // Test platform
+        let t = TemplateString::from("{{ pixi.platform }}");
+        assert_eq!(t.render(&context).unwrap(), "linux-64");
+
+        // Test is_linux
+        let t = TemplateString::from("{{ pixi.is_linux }}");
+        assert_eq!(t.render(&context).unwrap(), "true");
+
+        // Test is_win
+        let t = TemplateString::from("{{ pixi.is_win }}");
+        assert_eq!(t.render(&context).unwrap(), "false");
+
+        // Test environment
+        let t = TemplateString::from("{{ pixi.environment.name }}");
+        assert_eq!(t.render(&context).unwrap(), "test-env");
+
+        // Test manifest_path
+        let t = TemplateString::from("{{ pixi.manifest_path }}");
+        assert_eq!(t.render(&context).unwrap(), "/tmp/pixi.toml");
+
+        // Test version
+        let t = TemplateString::from("{{ pixi.version }}");
+        assert!(t.render(&context).unwrap().contains("."));
     }
 
     #[test]
@@ -953,9 +1117,44 @@ mod tests {
             name: "foo".into(),
             value: "bar".into(),
         }]);
-        let rendered = t
-            .render(Some(&args))
-            .expect("should render with typed args");
+        let context = TaskRenderContext {
+            args: Some(&args),
+            ..TaskRenderContext::default()
+        };
+        let rendered = t.render(&context).expect("should render with typed args");
         assert_eq!(rendered, "echo bar");
     }
+
+    #[test]
+    fn test_template_string_renders_platform_variable() {
+        let t = TemplateString::from("echo {{ pixi.platform }}");
+        let args = ArgValues::TypedArgs(vec![]);
+        let context = TaskRenderContext {
+            platform: Platform::Linux64,
+            args: Some(&args),
+            ..TaskRenderContext::default()
+        };
+        let rendered = t.render(&context).expect("should render platform variable");
+
+        assert_eq!(rendered, "echo linux-64");
+    }
+
+    #[test]
+    fn test_template_string_renders_with_platform_and_args() {
+        let t = TemplateString::from("build-{{ pixi.platform }}-{{ version }}");
+        let args = ArgValues::TypedArgs(vec![TypedArg {
+            name: "version".into(),
+            value: "1.0.0".into(),
+        }]);
+        let context = TaskRenderContext {
+            platform: Platform::Linux64,
+            args: Some(&args),
+            ..TaskRenderContext::default()
+        };
+        let rendered = t
+            .render(&context)
+            .expect("should render with platform and args");
+
+        assert_eq!(rendered, "build-linux-64-1.0.0");
+    }
 }
