@@ -8,7 +8,8 @@ use pep440_rs::{Version, VersionSpecifiers};
 use pep508_rs::Requirement;
 use pixi_toml::{DeserializeAs, Same, TomlFromStr, TomlIndexMap, TomlWith};
 use pyproject_toml::{
-    BuildSystem, Contact, DependencyGroupSpecifier, DependencyGroups, License, Project, ReadMe,
+    self, BuildSystem, Contact, DependencyGroupSpecifier, DependencyGroups, License, Project,
+    ReadMe,
 };
 use toml_span::{
     DeserError, Deserialize, Error, ErrorKind, Spanned, Value,
@@ -25,6 +26,19 @@ pub struct PyProjectToml {
     pub dependency_groups: Option<Spanned<TomlDependencyGroups>>,
 }
 
+impl PyProjectToml {
+    pub fn into_inner(self) -> pyproject_toml::PyProjectToml {
+        pyproject_toml::PyProjectToml {
+            project: self.project.map(TomlProject::into_inner),
+            build_system: self.build_system.map(TomlBuildSystem::into_inner),
+            dependency_groups: self
+                .dependency_groups
+                .map(Spanned::take)
+                .map(TomlDependencyGroups::into_inner),
+        }
+    }
+}
+
 impl<'de> toml_span::Deserialize<'de> for PyProjectToml {
     fn deserialize(value: &mut Value<'de>) -> Result<Self, DeserError> {
         let mut th = TableHelper::new(value)?;
