@@ -128,12 +128,25 @@ impl<'p> ExecutableTask<'p> {
         &self.args
     }
 
+    /// Creates a properly populated `TaskRenderContext` for this task.
+    ///
+    /// This includes the platform, environment name, manifest path, and arguments.
+    pub fn render_context(&self) -> pixi_manifest::task::TaskRenderContext {
+        pixi_manifest::task::TaskRenderContext {
+            platform: self.run_environment.best_platform(),
+            environment_name: self.run_environment.name(),
+            manifest_path: Some(&self.workspace.workspace.provenance.path),
+            args: Some(&self.args),
+        }
+    }
+
     /// Returns the task as script
     fn as_script(&self) -> Result<Option<String>, FailedToParseShellScript> {
         // Convert the task into an executable string
+        let context = self.render_context();
         let task = self
             .task
-            .as_single_command(Some(&self.args))
+            .as_single_command(&context)
             .map_err(FailedToParseShellScript::ArgumentReplacement)?;
         if let Some(task) = task {
             // Get the export specific environment variables
@@ -207,9 +220,10 @@ impl<'p> ExecutableTask<'p> {
     /// This function returns `None` if the task does not define a command to
     /// execute. This is the case for alias only commands.
     pub fn full_command(&self) -> Result<Option<String>, TemplateStringError> {
+        let context = self.render_context();
         let original_cmd = self
             .task
-            .as_single_command(Some(&self.args))?
+            .as_single_command(&context)?
             .map(|c| c.into_owned());
 
         if let Some(mut cmd) = original_cmd {
@@ -305,14 +319,15 @@ impl<'p> ExecutableTask<'p> {
     pub fn warn_on_missing_globs(&self, post_hash: &TaskHash) {
         let (rendered_inputs, rendered_outputs) = match self.task().as_execute() {
             Ok(exe) => {
+                let context = self.render_context();
                 let ins = exe
                     .inputs
                     .as_ref()
-                    .map(|p| p.render(Some(self.args())).unwrap_or_default());
+                    .map(|p| p.render(&context).unwrap_or_default());
                 let outs = exe
                     .outputs
                     .as_ref()
-                    .map(|p| p.render(Some(self.args())).unwrap_or_default());
+                    .map(|p| p.render(&context).unwrap_or_default());
                 (ins, outs)
             }
             Err(_) => (None, None),
@@ -429,7 +444,8 @@ struct ExecutableTaskConsoleDisplay<'p, 't> {
 
 impl Display for ExecutableTaskConsoleDisplay<'_, '_> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        match self.task.task.as_single_command(Some(&self.task.args)) {
+        let context = self.task.render_context();
+        match self.task.task.as_single_command(&context) {
             Ok(command) => {
                 write!(
                     f,
