@@ -1,14 +1,35 @@
 #!/bin/sh
 set -eu
-# Version: v0.59.0
+# Version: v0.60.0
 
 __wrap__() {
+    # Function to mask username and password in URLs for safe printing
+    # Usage: mask_credentials "url"
+    # Returns the URL with credentials replaced by ***:***@
+    #
+    # [^:@/]+ - This matches the username part:
+    #   - [^:@/] means "any character EXCEPT :, @, or /"
+    #   - + means "one or more of these characters"
+    #   - So it captures everything up until it hits a colon, at-sign, or slash
+    #   - : - Matches the literal colon that separates username from password
+    #
+    # [^@/]+ - This matches the password part:
+    #   - [^@/] means "any character EXCEPT @ or /"
+    #   - + means "one or more of these characters"
+    #   - So it captures everything after the colon until it hits an at-sign or slash
+    #   - @ - Matches the literal at-sign that
+    mask_credentials() {
+        URL="$1"
+        # Use sed to replace username:password@ pattern with ***:***@
+        echo "$URL" | sed -E 's|://[^:@/]+:[^@/]+@|://***:***@|g'
+    }
+
     VERSION="${PIXI_VERSION:-latest}"
     PIXI_HOME="${PIXI_HOME:-$HOME/.pixi}"
     case "$PIXI_HOME" in
     '~' | '~'/*) PIXI_HOME="${HOME-}${PIXI_HOME#\~}" ;; # expand tilde
     esac
-    BIN_DIR="$PIXI_HOME/bin"
+    PIXI_BIN_DIR="${PIXI_BIN_DIR:-$PIXI_HOME/bin}"
 
     REPOURL="${PIXI_REPOURL:-https://github.com/prefix-dev/pixi}"
     PLATFORM="$(uname -s)"
@@ -38,13 +59,13 @@ __wrap__() {
     fi
 
     if [ "$VERSION" = "latest" ]; then
-        DOWNLOAD_URL="${REPOURL%/}/releases/latest/download/${BINARY}${EXTENSION-}"
+        DOWNLOAD_URL="${PIXI_DOWNLOAD_URL:-${REPOURL%/}/releases/latest/download/${BINARY}${EXTENSION-}}"
     else
         # Check if version is incorrectly specified without prefix 'v', and prepend 'v' in this case
-        DOWNLOAD_URL="${REPOURL%/}/releases/download/v${VERSION#v}/${BINARY}${EXTENSION-}"
+        DOWNLOAD_URL="${PIXI_DOWNLOAD_URL:-${REPOURL%/}/releases/download/v${VERSION#v}/${BINARY}${EXTENSION-}}"
     fi
 
-    printf "This script will automatically download and install Pixi (%s) for you.\nGetting it from this url: %s\n" "$VERSION" "$DOWNLOAD_URL"
+    printf "This script will automatically download and install Pixi (%s) for you.\nGetting it from this url: %s\n" "$VERSION" "$(mask_credentials "$DOWNLOAD_URL")"
 
     HAVE_CURL=false
     HAVE_CURL_8_8_0=false
@@ -93,33 +114,46 @@ __wrap__() {
         WGET_OPTIONS="--show-progress"
     fi
 
+    # Use .netrc for authentication - prioritize NETRC env var over default location
+    if [ -n "${NETRC:-}" ]; then
+        CURL_OPTIONS="$CURL_OPTIONS --netrc-file $NETRC"
+        WGET_OPTIONS="$WGET_OPTIONS --netrc-file=$NETRC"
+    elif [ -f "$HOME/.netrc" ]; then
+        CURL_OPTIONS="$CURL_OPTIONS --netrc"
+        WGET_OPTIONS="$WGET_OPTIONS --netrc"
+    fi
+
     if $HAVE_CURL; then
         CURL_ERR=0
         HTTP_CODE="$(curl -SL $CURL_OPTIONS "$DOWNLOAD_URL" --output "$TEMP_FILE" --write-out "%{http_code}")" || CURL_ERR=$?
         case "$CURL_ERR" in
         35 | 53 | 54 | 59 | 66 | 77)
             if ! $HAVE_WGET; then
-                echo "error: when download '${DOWNLOAD_URL}', curl has some local ssl problems with error $CURL_ERR" >&2
+                echo "error: when download '$(mask_credentials "$DOWNLOAD_URL")', curl has some local ssl problems with error $CURL_ERR" >&2
                 exit 1
             fi
             # fallback to wget
             ;;
         0)
-            if [ "${HTTP_CODE}" -lt 200 ] || [ "${HTTP_CODE}" -gt 299 ]; then
-                echo "error: '${DOWNLOAD_URL}' is not available" >&2
+            if [ "${HTTP_CODE}" -eq 401 ]; then
+                echo "error: authentication failed when downloading '$(mask_credentials "$DOWNLOAD_URL")'" >&2
+                echo "       Check your .netrc file, NETRC environment variable, or the hardcoded credentials in PIXI_DOWNLOAD_URL." >&2
+                exit 1
+            elif [ "${HTTP_CODE}" -lt 200 ] || [ "${HTTP_CODE}" -gt 299 ]; then
+                echo "error: '$(mask_credentials "$DOWNLOAD_URL")' is not available (HTTP ${HTTP_CODE})" >&2
                 exit 1
             fi
             HAVE_WGET=false # download success, skip wget
             ;;
         *)
-            echo "error: when download '${DOWNLOAD_URL}', curl fails with with error $CURL_ERR" >&2
+            echo "error: when download '$(mask_credentials "$DOWNLOAD_URL")', curl fails with error $CURL_ERR" >&2
             exit 1
             ;;
         esac
     fi
 
     if $HAVE_WGET && ! wget $WGET_OPTIONS --output-document="$TEMP_FILE" "$DOWNLOAD_URL"; then
-        echo "error: '${DOWNLOAD_URL}' is not available" >&2
+        echo "error: '$(mask_credentials "$DOWNLOAD_URL")' is not available" >&2
         exit 1
     fi
 
@@ -131,9 +165,9 @@ __wrap__() {
     fi
 
     # Extract pixi from the downloaded file
-    mkdir -p "$BIN_DIR"
+    mkdir -p "$PIXI_BIN_DIR"
     if [ "${EXTENSION-}" = ".zip" ]; then
-        unzip "$TEMP_FILE" -d "$BIN_DIR"
+        unzip "$TEMP_FILE" -d "$PIXI_BIN_DIR"
     elif [ "${EXTENSION-}" = ".tar.gz" ]; then
         # Extract to a temporary directory first
         TEMP_DIR=$(mktemp -d)
@@ -141,21 +175,21 @@ __wrap__() {
 
         # Find and move the `pixi` binary, making sure to handle the case where it's in a subdirectory
         if [ -f "$TEMP_DIR/pixi" ]; then
-            mv "$TEMP_DIR/pixi" "$BIN_DIR/"
+            mv "$TEMP_DIR/pixi" "$PIXI_BIN_DIR/"
         else
-            mv "$(find "$TEMP_DIR" -type f -name pixi)" "$BIN_DIR/"
+            mv "$(find "$TEMP_DIR" -type f -name pixi)" "$PIXI_BIN_DIR/"
         fi
 
-        chmod +x "$BIN_DIR/pixi"
+        chmod +x "$PIXI_BIN_DIR/pixi"
         rm -rf "$TEMP_DIR"
     elif [ "${EXTENSION-}" = ".exe" ]; then
-        cp -f "$TEMP_FILE" "$BIN_DIR/pixi.exe"
+        cp -f "$TEMP_FILE" "$PIXI_BIN_DIR/pixi.exe"
     else
         chmod +x "$TEMP_FILE"
-        cp -f "$TEMP_FILE" "$BIN_DIR/pixi"
+        cp -f "$TEMP_FILE" "$PIXI_BIN_DIR/pixi"
     fi
 
-    echo "The 'pixi' binary is installed into '${BIN_DIR}'"
+    echo "The 'pixi' binary is installed into '${PIXI_BIN_DIR}'"
 
     # shell update can be suppressed by `PIXI_NO_PATH_UPDATE` env var
     if [ -n "${PIXI_NO_PATH_UPDATE:-}" ]; then
@@ -181,33 +215,33 @@ __wrap__() {
         case "$(basename "${SHELL-}")" in
         bash)
             # Default to bashrc as that is used in non login shells instead of the profile.
-            LINE="export PATH=\"${BIN_DIR}:\$PATH\""
+            LINE="export PATH=\"${PIXI_BIN_DIR}:\$PATH\""
             update_shell ~/.bashrc "$LINE"
             ;;
 
         fish)
-            LINE="fish_add_path ${BIN_DIR}"
+            LINE="fish_add_path ${PIXI_BIN_DIR}"
             update_shell ~/.config/fish/config.fish "$LINE"
             ;;
 
         zsh)
-            LINE="export PATH=\"${BIN_DIR}:\$PATH\""
+            LINE="export PATH=\"${PIXI_BIN_DIR}:\$PATH\""
             update_shell ~/.zshrc "$LINE"
             ;;
 
         tcsh)
-            LINE="set path = ( ${BIN_DIR} \$path )"
+            LINE="set path = ( ${PIXI_BIN_DIR} \$path )"
             update_shell ~/.tcshrc "$LINE"
             ;;
 
         '')
             echo "warn: Could not detect shell type." >&2
-            echo "      Please permanently add '${BIN_DIR}' to your \$PATH to enable the 'pixi' command." >&2
+            echo "      Please permanently add '${PIXI_BIN_DIR}' to your \$PATH to enable the 'pixi' command." >&2
             ;;
 
         *)
             echo "warn: Could not update shell $(basename "$SHELL")" >&2
-            echo "      Please permanently add '${BIN_DIR}' to your \$PATH to enable the 'pixi' command." >&2
+            echo "      Please permanently add '${PIXI_BIN_DIR}' to your \$PATH to enable the 'pixi' command." >&2
             ;;
         esac
     fi
