@@ -14,6 +14,7 @@ import tomli
 import tomli_w
 
 from .common import (
+    CURRENT_PLATFORM,
     EMPTY_BOILERPLATE_PROJECT,
     ExitCode,
     default_env_path,
@@ -1412,6 +1413,62 @@ def test_task_caching_with_multiple_inputs_args(pixi: Path, tmp_pixi_workspace:
     )
 
 
+def test_task_caching_when_running_already_cached_depends_task(
+    pixi: Path, tmp_pixi_workspace: Path
+) -> None:
+    """Test executing the cached task with depends-on should reuse the cache."""
+    manifest_path = tmp_pixi_workspace.joinpath("pixi.toml")
+
+    # create the input folder
+    # that will be tests if they are cached hit
+    input_dir = tmp_pixi_workspace.joinpath("inputs")
+    input_dir.mkdir(exist_ok=True)
+
+    input_file = input_dir.joinpath("file1.txt")
+    input_file.write_text("Content for file1")
+
+    toml_content = f"""
+[workspace]
+name = "test"
+channels = []
+platforms = ["{CURRENT_PLATFORM}"]
+
+
+[tasks]
+process-file = {{ cmd = "echo Processing $(cat inputs/file1.txt)", inputs = ["inputs/file1.txt"] }}
+multiple-depends = {{ cmd = "echo hello from depends", depends-on = [{{ task = "process-file" }}] }}
+
+"""
+
+    manifest_path.write_text(toml_content)
+
+    # Run first time without being cached
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "process-file"],
+        stderr_contains=[
+            "Processing $(cat inputs/file1.txt)",
+        ],
+        stderr_excludes=[
+            "cache hit",
+        ],
+    )
+
+    # Should have a cache hit the second time
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "process-file"],
+        stderr_contains=["Processing $(cat inputs/file1.txt)", "cache hit"],
+    )
+
+    # Run the task with depends-on, that should be cached
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "multiple-depends"],
+        stderr_contains=[
+            "file1",
+            "cache hit",
+        ],
+    )
+
+
 def test_caching_multiple_tasks_with_depends_on_args(pixi: Path, tmp_pixi_workspace: Path) -> None:
     """Test ``depends-on`` with the same inputs, outputs, but different args, are cached independently.
 
